@@ -1,5 +1,5 @@
 /*
- * $Id: action.c 1827 2007-03-12 15:22:53Z bogdan_iancu $
+ * $Id: action.c 2837 2007-10-03 10:19:25Z miconda $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  * Copyright (C) 2005-2006 Voice Sistem S.R.L.
@@ -80,6 +80,7 @@
 
 int action_flags = 0;
 int return_code  = 0;
+int max_while_loops = 100;
 
 static int rec_lev=0;
 
@@ -95,14 +96,14 @@ static inline int run_actions(struct action* a, struct sip_msg* msg)
 
 	rec_lev++;
 	if (rec_lev>ROUTE_MAX_REC_LEV){
-		LOG(L_ERR, "ERROR:run_action: too many recursive routing "
-				"table lookups (%d) giving up!\n", rec_lev);
+		LM_ERR("too many recursive routing table lookups (%d) giving up!\n",
+			rec_lev);
 		ret=E_UNSPEC;
 		goto error;
 	}
 
 	if (a==0){
-		LOG(L_WARN, "WARNING: run_actions: null action list (rec_level=%d)\n", 
+		LM_WARN("null action list (rec_level=%d)\n", 
 			rec_lev);
 		ret=1;
 		goto error;
@@ -136,7 +137,7 @@ int run_action_list(struct action* a, struct sip_msg* msg)
 				&& !is_route_type(ONREPLY_ROUTE)
 				&& _oser_err_info.eclass!=0)
 		{
-			DBG("run_action_list: jumping to error route\n");
+			LM_DBG("jumping to error route\n");
 			set_route_type( ERROR_ROUTE );
 			run_actions(error_rlist, msg);
 			/* if don't exit, then reset error info */
@@ -182,29 +183,30 @@ int run_top_route(struct action* a, struct sip_msg* msg)
 int do_assign(struct sip_msg* msg, struct action* a)
 {
 	int ret;
-	xl_value_t val;
-	int_str avp_name;
-	int_str avp_val;
-	int flags;
-	unsigned short name_type;
-	xl_spec_p dspec;
-	struct action  act;
-	char backup;
+	pv_value_t val;
+	pv_spec_p dspec;
 
 	ret = -1;
-	memset(&val, 0, sizeof(xl_value_t));
+	dspec = (pv_spec_p)a->elem[0].u.data;
+	if(!pv_is_w(dspec))
+	{
+		LM_ERR("read only PV in left expression\n");
+		goto error;
+	}
+
+	memset(&val, 0, sizeof(pv_value_t));
 	if(a->elem[1].type != NULLV_ST)
 	{
 		ret = eval_expr((struct expr*)a->elem[1].u.data, msg, &val);
-		if(!((val.flags&XL_VAL_STR)||(val.flags&XL_VAL_INT))) {
-			LOG(L_ERR, "do_assign: no value in right expression\n");
+		if(!((val.flags&PV_VAL_STR)||(val.flags&PV_VAL_INT))) {
+			LM_ERR("no value in right expression\n");
 			goto error;
 		}
 	}
 
-	dspec = (xl_spec_p)a->elem[0].u.data;
 	switch ((unsigned char)a->type){
 		case EQ_T:
+		case COLONEQ_T:
 		case PLUSEQ_T:
 		case MINUSEQ_T:
 		case DIVEQ_T:
@@ -213,148 +215,33 @@ int do_assign(struct sip_msg* msg, struct action* a)
 		case BANDEQ_T:
 		case BOREQ_T:
 		case BXOREQ_T:
-			switch(dspec->type) {
-				case XL_AVP:
-					if(xl_get_avp_name(msg, dspec, &avp_name, &name_type)!=0)
-					{
-						LOG(L_ERR, "BUG:avpops:ops_printf: error getting"
-								" dst AVP name\n");
-						goto error;
-					}
-					if(a->elem[1].type == NULLV_ST)
-					{
-						destroy_avps(name_type, avp_name, 0);
-						return 1;
-					}
-
-					flags = name_type;
-					if(val.flags&XL_TYPE_INT)
-					{
-						avp_val.n = val.ri;
-					} else {
-						avp_val.s = val.rs;
-						flags |= AVP_VAL_STR;
-					}
-
-					if (add_avp(flags, avp_name, avp_val)<0)
-					{
-						LOG(L_ERR, "do_assign: error - cannot add AVP\n");
-						goto error;
-					}
-
-				break;
-				case XL_SCRIPTVAR:
-					if(dspec->p.data==0)
-					{
-						LOG(L_ERR, "do_assign: error - cannot find svar\n");
-						goto error;
-					}
-					if(a->elem[1].type == NULLV_ST)
-					{
-						avp_val.n = 0;
-						set_var_value((script_var_t*)dspec->p.data,&avp_val,0);
-						return 1;
-					}
-					flags = 0;
-					if(val.flags&XL_TYPE_INT)
-					{
-						avp_val.n = val.ri;
-					} else {
-						avp_val.s = val.rs;
-						flags |= VAR_VAL_STR;
-					}
-					if(set_var_value((script_var_t*)dspec->p.data,
-								&avp_val, flags)==NULL)
-					{
-						LOG(L_ERR,
-							"do_assign: error - cannot set svar [%.*s]\n",
-							dspec->p.val.len, dspec->p.val.s);
-						goto error;
-					}
-				break;
-				case XL_RURI_USERNAME:
-					if(a->elem[1].type == NULLV_ST)
-					{
-						memset(&act, 0, sizeof(act));
-						act.type = SET_USER_T;
-						act.elem[0].type = STRING_ST;
-						act.elem[0].u.string = "";
-						if (do_action(&act, msg)<0)
-						{
-							LOG(L_ERR,
-								"do_assign: error - do action failed %d\n",
-								act.type);
-							goto error;
-						}
-						return 1;
-					}
-				case XL_RURI_DOMAIN:
-				case XL_RURI:
-					if(!(val.flags&XL_VAL_STR))
-					{
-						LOG(L_ERR,"do_assign: error - str value requred to"
-								" set R-URI parts\n");
-						goto error;
-					}
-					memset(&act, 0, sizeof(act));
-					act.elem[0].type = STRING_ST;
-					act.elem[0].u.string = val.rs.s;
-					backup = val.rs.s[val.rs.len];
-					val.rs.s[val.rs.len] = '\0';
-					if(dspec->type==XL_RURI_USERNAME)
-						act.type = SET_USER_T;
-					else if(dspec->type==XL_RURI_DOMAIN)
-						act.type = SET_HOST_T;
-					else
-						act.type = SET_URI_T;
-					if (do_action(&act, msg)<0)
-					{
-						LOG(L_ERR,"do_assign: error - do action failed %d\n",
-								act.type);
-						val.rs.s[val.rs.len] = backup;
-						goto error;
-					}
-					val.rs.s[val.rs.len] = backup;
-				break;
-				case XL_DSTURI:
-					if(a->elem[1].type == NULLV_ST)
-					{
-						memset(&act, 0, sizeof(act));
-						act.type = RESET_DSTURI_T;
-						if (do_action(&act, msg)<0)
-						{
-							LOG(L_ERR,
-								"do_assign: error - do action failed %d\n",
-								act.type);
-							goto error;
-						}
-						return 1;
-					}
-					if(!(val.flags&XL_VAL_STR))
-					{
-						LOG(L_ERR,"do_assign: error - str value requred to"
-							" set dst uri\n");
-						goto error;
-					}
-					if(set_dst_uri(msg, &val.rs)!=0)
-						goto error;
-				break;
-				default:
-					LOG(L_ERR, "do_assign: error - unknown dst var\n");
-					return E_BUG;
+			if(a->elem[1].type == NULLV_ST)
+			{
+				if(dspec->setf(msg, &dspec->pvp, (int)a->type, 0)<0)
+				{
+					LM_ERR("setting PV failed\n");
+					goto error;
+				}
+			} else {
+				if(dspec->setf(msg, &dspec->pvp, (int)a->type, &val)<0)
+				{
+					LM_ERR("setting PV failed\n");
+					goto error;
+				}
 			}
-
-			xl_value_destroy(&val);
-			return 1;
+			ret = 1;
+		break;
 		default:
-			LOG(L_CRIT, "BUG: do_assign: unknown type %d\n", a->type);
+			LM_ALERT("BUG -> unknown op type %d\n", a->type);
+			goto error;
 	}
 
-	xl_value_destroy(&val);
+	pv_value_destroy(&val);
 	return ret;
 
 error:
-	xl_value_destroy(&val);
+	LM_ERR("error at line: %d\n", a->line);
+	pv_value_destroy(&val);
 	return -1;
 }
 
@@ -377,8 +264,9 @@ int do_action(struct action* a, struct sip_msg* msg)
 	int cmatch;
 	struct action *aitem;
 	struct action *adefault;
-	xl_spec_t *spec;
-	xl_value_t val;
+	pv_spec_t *spec;
+	pv_elem_p model;
+	pv_value_t val;
 
 	/* reset the value of error to E_UNSPEC so avoid unknowledgable
 	   functions to return with error (status<0) and not setting it
@@ -411,44 +299,40 @@ int do_action(struct action* a, struct sip_msg* msg)
 					u = &msg->parsed_uri;
 				}
 				if (ret<0) {
-					LOG(L_ERR, "ERROR: do_action: forward: bad_uri "
-								" dropping packet\n");
+					LM_ERR("forward: bad_uri dropping packet\n");
 					break;
 				}
 				/* create a temporary proxy*/
 				p=mk_proxy(&u->host, u->port_no, u->proto,
 					(u->type==SIPS_URI_T)?1:0 );
 				if (p==0){
-					LOG(L_ERR, "ERROR:  bad host name in uri,"
-							" dropping packet\n");
+					LM_ERR("bad host name in uri, dropping packet\n");
 					ret=E_BAD_ADDRESS;
 					goto error_fwd_uri;
 				}
 				ret=forward_request(msg, p);
 				free_proxy(p); /* frees only p content, not p itself */
 				pkg_free(p);
-				if (ret>=0) ret=1;
+				if (ret==0) ret=1;
 			}else if ((a->elem[0].type==PROXY_ST)) {
 				ret=forward_request(msg,(struct proxy_l*)a->elem[0].u.data);
-				if (ret>=0) ret=1;
+				if (ret==0) ret=1;
 			}else{
-				LOG(L_CRIT, "BUG: do_action: bad forward() types %d, %d\n",
+				LM_ALERT("BUG in forward() types %d, %d\n",
 						a->elem[0].type, a->elem[1].type);
 				ret=E_BUG;
 			}
 			break;
 		case SEND_T:
 			if (a->elem[0].type!= PROXY_ST){
-				LOG(L_CRIT,"BUG: do_action: bad send() type %d\n",
-						a->elem[0].type);
+				LM_ALERT("BUG in send() type %d\n", a->elem[0].type);
 				ret=E_BUG;
 				break;
 			}
 			to=(union sockaddr_union*)
 					pkg_malloc(sizeof(union sockaddr_union));
 			if (to==0){
-				LOG(L_ERR, "ERROR: do_action: "
-							"memory allocation failure\n");
+				LM_ERR("memory allocation failure\n");
 				ret=E_OUT_OF_MEM;
 				break;
 			}
@@ -464,12 +348,12 @@ int do_action(struct action* a, struct sip_msg* msg)
 					p->addr_idx++;
 			}
 			pkg_free(to);
-			if (ret>=0)
+			if (ret==0)
 				ret=1;
 			break;
 		case LOG_T:
 			if ((a->elem[0].type!=NUMBER_ST)|(a->elem[1].type!=STRING_ST)){
-				LOG(L_CRIT, "BUG: do_action: bad log() types %d, %d\n",
+				LM_ALERT("BUG in log() types %d, %d\n",
 						a->elem[0].type, a->elem[1].type);
 				ret=E_BUG;
 				break;
@@ -480,7 +364,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 		case APPEND_BRANCH_T:
 			/* WARNING: even if type is STRING_ST, it expects a str !!!*/
 			if ((a->elem[0].type!=STRING_ST)) {
-				LOG(L_CRIT, "BUG: do_action: bad append_branch_t %d\n",
+				LM_ALERT("BUG in append_branch %d\n",
 					a->elem[0].type );
 				ret=E_BUG;
 				break;
@@ -502,13 +386,20 @@ int do_action(struct action* a, struct sip_msg* msg)
 			break;
 		case LEN_GT_T:
 			if (a->elem[0].type!=NUMBER_ST) {
-				LOG(L_CRIT, "BUG: do_action: bad len_gt type %d\n",
+				LM_ALERT("BUG in len_gt type %d\n",
 					a->elem[0].type );
 				ret=E_BUG;
 				break;
 			}
 			ret = (msg->len >= (unsigned int)a->elem[0].u.number) ? 1 : -1;
 			break;
+		case SET_DEBUG_T:
+			if (a->elem[0].type==NUMBER_ST)
+				set_proc_debug_level(a->elem[0].u.number);
+			else
+				reset_proc_debug_level();
+			ret = 1;
+			break;
 		case SETFLAG_T:
 			ret = setflag( msg, a->elem[0].u.number );
 			break;
@@ -538,31 +429,31 @@ int do_action(struct action* a, struct sip_msg* msg)
 			break;
 		case ERROR_T:
 			if ((a->elem[0].type!=STRING_ST)|(a->elem[1].type!=STRING_ST)){
-				LOG(L_CRIT, "BUG: do_action: bad error() types %d, %d\n",
+				LM_ALERT("BUG in error() types %d, %d\n",
 						a->elem[0].type, a->elem[1].type);
 				ret=E_BUG;
 				break;
 			}
-			LOG(L_NOTICE, "WARNING: do_action: error(\"%s\", \"%s\") "
+			LM_WARN("error(\"%s\", \"%s\") "
 					"not implemented yet\n", a->elem[0].u.string,
 					a->elem[1].u.string);
 			ret=1;
 			break;
 		case ROUTE_T:
 			if (a->elem[0].type!=NUMBER_ST){
-				LOG(L_CRIT, "BUG: do_action: bad route() type %d\n",
+				LM_ALERT("BUG in route() type %d\n",
 						a->elem[0].type);
 				ret=E_BUG;
 				break;
 			}
 			if ((a->elem[0].u.number>RT_NO)||(a->elem[0].u.number<0)){
-				LOG(L_ERR, "ERROR: invalid routing table number in"
+				LM_ALERT("BUG - invalid routing table number in"
 							"route(%lu)\n", a->elem[0].u.number);
 				ret=E_CFG;
 				break;
 			}
 			return_code=run_actions(rlist[a->elem[0].u.number], msg);
-			ret=(return_code<0)?return_code:1;
+			ret=return_code;
 			break;
 		case REVERT_URI_T:
 			if (msg->new_uri.s) {
@@ -585,12 +476,12 @@ int do_action(struct action* a, struct sip_msg* msg)
 				user=0;
 				if (a->type==STRIP_T || a->type==STRIP_TAIL_T) {
 					if (a->elem[0].type!=NUMBER_ST) {
-						LOG(L_CRIT, "BUG: do_action: bad set*() type %d\n",
+						LM_ALERT("BUG in set*() type %d\n",
 							a->elem[0].type);
 						break;
 					}
 				} else if (a->elem[0].type!=STRING_ST){
-					LOG(L_CRIT, "BUG: do_action: bad set*() type %d\n",
+					LM_ALERT("BUG in set*() type %d\n",
 							a->elem[0].type);
 					ret=E_BUG;
 					break;
@@ -604,8 +495,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 					len=strlen(a->elem[0].u.string);
 					msg->new_uri.s=pkg_malloc(len+1);
 					if (msg->new_uri.s==0){
-						LOG(L_ERR, "ERROR: do_action: memory allocation"
-								" failure\n");
+						LM_ERR("memory allocation failure\n");
 						ret=E_OUT_OF_MEM;
 						break;
 					}
@@ -624,15 +514,14 @@ int do_action(struct action* a, struct sip_msg* msg)
 					len=msg->first_line.u.request.uri.len;
 				}
 				if (parse_uri(tmp, len, &uri)<0){
-					LOG(L_ERR, "ERROR: do_action: bad uri <%s>, dropping"
-								" packet\n", tmp);
+					LM_ERR("bad uri <%s>, dropping packet\n", tmp);
 					ret=E_UNSPEC;
 					break;
 				}
 				
 				new_uri=pkg_malloc(MAX_URI_SIZE);
 				if (new_uri==0){
-					LOG(L_ERR, "ERROR: do_action: memory allocation failure\n");
+					LM_ERR("memory allocation failure\n");
 					ret=E_OUT_OF_MEM;
 					break;
 				}
@@ -656,7 +545,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 					len=strlen(tmp);
 				} else if (a->type==STRIP_T) {
 					if (a->elem[0].u.number>uri.user.len) {
-						LOG(L_WARN, "Error: too long strip asked; "
+						LM_WARN("too long strip asked; "
 								" deleting username: %lu of <%.*s>\n",
 								a->elem[0].u.number, uri.user.len, uri.user.s);
 						len=0;
@@ -668,7 +557,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 					}
 				} else if (a->type==STRIP_TAIL_T) {
 					if (a->elem[0].u.number>uri.user.len) {
-						LOG(L_WARN, "WARNING: too long strip_tail asked;"
+						LM_WARN("too long strip_tail asked;"
 								" deleting username: %lu of <%.*s>\n",
 								a->elem[0].u.number, uri.user.len, uri.user.s);
 						len=0;
@@ -754,7 +643,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 		case SET_DSTURI_T:
 			/* WARNING: even if type is STRING_ST, it expects a str !!!*/
 			if (a->elem[0].type!=STRING_ST){
-				LOG(L_CRIT, "BUG: do_action: bad setdsturi() type %d\n",
+				LM_ALERT("BUG in setdsturi() type %d\n",
 							a->elem[0].type);
 				ret=E_BUG;
 				break;
@@ -790,8 +679,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 							return_code = 0;
 							break;
 						}else{
-							LOG(L_WARN,"WARNING: do_action:"
-										"error in expression\n");
+							LM_WARN("error in expression\n");
 						}
 					}
 					
@@ -811,23 +699,68 @@ int do_action(struct action* a, struct sip_msg* msg)
 					}
 				}
 			break;
+		case WHILE_T:
+				/* if null expr => ignore if? */
+				if ((a->elem[0].type==EXPR_ST)&&a->elem[0].u.data){
+					len = 0;
+					while(1)
+					{
+						if(len++ >= max_while_loops)
+						{
+							LM_INFO("max while loops are encountered\n");
+							break;
+						}
+						v=eval_expr((struct expr*)a->elem[0].u.data, msg, 0);
+						/* set return code to expr value */
+						if (v<0 || (action_flags&ACT_FL_RETURN)
+								|| (action_flags&ACT_FL_EXIT) ){
+							if (v==EXPR_DROP || (action_flags&ACT_FL_RETURN)
+									|| (action_flags&ACT_FL_EXIT) ){
+								ret=0;
+								return_code = 0;
+								break;
+							}else{
+								LM_WARN("error in expression\n");
+							}
+						}
+					
+						ret=1;  /*default is continue */
+						if (v>0) {
+							if ((a->elem[1].type==ACTIONS_ST)
+									&&a->elem[1].u.data){
+								ret=run_action_list(
+										(struct action*)a->elem[1].u.data,msg );
+								return_code = ret;
+							} else {
+								/* we should not get here */
+								return_code = v;
+								break;
+							}
+						} else {
+							/* condition was false */
+							return_code = v;
+							break;
+						}
+					}
+				}
+			break;
 		case SWITCH_T:
 			if (a->elem[0].type!=SCRIPTVAR_ST){
-				LOG(L_CRIT, "BUG: do_action: bad switch() type %d\n",
+				LM_ALERT("BUG in switch() type %d\n",
 						a->elem[0].type);
 				ret=E_BUG;
 				break;
 			}
-			spec = (xl_spec_t*)a->elem[0].u.data;
-			if(xl_get_spec_value(msg, spec, &val, 0)!=0)
+			spec = (pv_spec_t*)a->elem[0].u.data;
+			if(pv_get_spec_value(msg, spec, &val)!=0)
 			{
-				LOG(L_ERR, "BUG: do_action: no value in switch()\n");
+				LM_ALERT("BUG - no value in switch()\n");
 				ret=E_BUG;
 				break;
 			}
 			/* get the value of pvar */
 			if(a->elem[1].type!=ACTIONS_ST) {
-				LOG(L_CRIT, "BUG: do_action: bad switch() actions\n");
+				LM_ALERT("BUG in switch() actions\n");
 				ret=E_BUG;
 				break;
 			}
@@ -843,13 +776,13 @@ int do_action(struct action* a, struct sip_msg* msg)
 				{
 					if(aitem->elem[0].type==STRING_ST)
 					{
-						if(val.flags&XL_VAL_STR
+						if(val.flags&PV_VAL_STR
 								&& val.rs.len==aitem->elem[0].u.s.len
 								&& strncasecmp(val.rs.s, aitem->elem[0].u.s.s,
 									val.rs.len)==0)
 							cmatch = 1;
 					} else { /* number */
-						if(val.flags&XL_VAL_INT && 
+						if(val.flags&PV_VAL_INT && 
 								val.ri==aitem->elem[0].u.number)
 							cmatch = 1;
 					}
@@ -871,19 +804,19 @@ int do_action(struct action* a, struct sip_msg* msg)
 			}
 			if((cmatch==0) && (adefault!=NULL))
 			{
-				DBG("do_action: swtich: running default statement\n");
+				LM_DBG("switch: running default statement\n");
 				if(adefault->elem[0].u.data)
 					return_code=run_action_list(
 						(struct action*)adefault->elem[0].u.data, msg);
 			}
-			ret=(return_code<0)?return_code:1;
+			ret=return_code;
 			break;
 		case MODULE_T:
 			if ( (a->elem[0].type==CMD_ST) && a->elem[0].u.data ) {
 				ret=((cmd_export_t*)(a->elem[0].u.data))->function(msg,
 						(char*)a->elem[1].u.data, (char*)a->elem[2].u.data);
 			}else{
-				LOG(L_CRIT,"BUG: do_action: bad module call\n");
+				LM_ALERT("BUG in module call\n");
 			}
 			break;
 		case FORCE_RPORT_T:
@@ -896,7 +829,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 			break;
 		case SET_ADV_ADDR_T:
 			if (a->elem[0].type!=STR_ST){
-				LOG(L_CRIT, "BUG: do_action: bad set_advertised_address() "
+				LM_ALERT("BUG in set_advertised_address() "
 						"type %d\n", a->elem[0].type);
 				ret=E_BUG;
 				break;
@@ -906,7 +839,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 			break;
 		case SET_ADV_PORT_T:
 			if (a->elem[0].type!=STR_ST){
-				LOG(L_CRIT, "BUG: do_action: bad set_advertised_port() "
+				LM_ALERT("BUG in set_advertised_port() "
 						"type %d\n", a->elem[0].type);
 				ret=E_BUG;
 				break;
@@ -926,7 +859,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 				else if (a->elem[0].type==NUMBER_ST)
 					port=(int)a->elem[0].u.number;
 				else{
-					LOG(L_CRIT, "BUG: do_action: bad force_tcp_alias"
+					LM_ALERT("BUG in force_tcp_alias"
 							" port type %d\n", a->elem[0].type);
 					ret=E_BUG;
 					break;
@@ -934,7 +867,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 						
 				if (tcpconn_add_alias(msg->rcv.proto_reserved1, port,
 									msg->rcv.proto)!=0){
-					LOG(L_ERR, " ERROR:do_action: tcp alias failed\n");
+					LM_ERR("tcp alias failed\n");
 					ret=E_UNSPEC;
 					break;
 				}
@@ -944,7 +877,7 @@ int do_action(struct action* a, struct sip_msg* msg)
 			break;
 		case FORCE_SEND_SOCKET_T:
 			if (a->elem[0].type!=SOCKETINFO_ST){
-				LOG(L_CRIT, "BUG: do_action: bad force_send_socket argument"
+				LM_ALERT("BUG in force_send_socket argument"
 						" type: %d\n", a->elem[0].type);
 				ret=E_BUG;
 				break;
@@ -954,13 +887,13 @@ int do_action(struct action* a, struct sip_msg* msg)
 			break;
 		case SERIALIZE_BRANCHES_T:
 			if (a->elem[0].type!=NUMBER_ST){
-				LOG(L_CRIT, "BUG: do_action: bad serialize_branches argument"
+				LM_ALERT("BUG in serialize_branches argument"
 						" type: %d\n", a->elem[0].type);
 				ret=E_BUG;
 				break;
 			}
 			if (serialize_branches(msg,(int)a->elem[0].u.number)!=0) {
-				LOG(L_ERR, "ERROR: do_action: serialize_branches failed\n");
+				LM_ERR("serialize_branches failed\n");
 				ret=E_UNSPEC;
 				break;
 			}
@@ -968,13 +901,14 @@ int do_action(struct action* a, struct sip_msg* msg)
 			break;
 		case NEXT_BRANCHES_T:
 			if (next_branches(msg)!=0) {
-				LOG(L_ERR, "ERROR: do_action: next_branches failed\n");
+				LM_ERR("next_branches failed\n");
 				ret=E_UNSPEC;
 				break;
 			}
 			ret=1; /* continue processing */
 			break;
 		case EQ_T:
+		case COLONEQ_T:
 		case PLUSEQ_T:
 		case MINUSEQ_T:
 		case DIVEQ_T:
@@ -988,28 +922,48 @@ int do_action(struct action* a, struct sip_msg* msg)
 		case USE_BLACKLIST_T:
 			mark_for_search((struct bl_head*)a->elem[0].u.data);
 			break;
-#ifdef TIMING_INFO
-		case SET_TIME_STAMP_T:
-				set_time_stamp(a->elem[0].u.string);
-			break;
-		case RESET_TIME_STAMP_T:
-				reset_time_stamp();
-			break;
-		case DIFF_TIME_STAMP_T:
-				diff_time_stamp(a->elem[0].u.number, a->elem[1].u.string);
-			break;
-#endif
+		case PV_PRINTF_T:
+			ret = -1;
+			spec = (pv_spec_p)a->elem[0].u.data;
+			if(!pv_is_w(spec))
+			{
+				LM_ERR("read only PV in first parameter of pv_printf\n");
+				goto error;
+			}
+
+			model = (pv_elem_p)a->elem[1].u.data;
+
+			memset(&val, 0, sizeof(pv_value_t));
+			if(pv_printf_s(msg, model, &val.rs)!=0)
+			{
+				LM_ERR("cannot eval second parameter\n");
+				goto error;
+			}
+			val.flags = PV_VAL_STR;
+			if(spec->setf(msg, &spec->pvp, EQ_T, &val)<0)
+			{
+				LM_ERR("setting PV failed\n");
+				goto error;
+			}
+			
+			ret = 1;
+		break;
 		default:
-			LOG(L_CRIT, "BUG: do_action: unknown type %d\n", a->type);
+			LM_ALERT("BUG - unknown type %d\n", a->type);
+			goto error;
 	}
 
 	if((unsigned char)a->type!=IF_T && (unsigned char)a->type!=ROUTE_T)
 		return_code = ret;
 /*skip:*/
 	return ret;
+
+error:
+	LM_ERR("error at line: %d\n", a->line);
+	return ret;
 	
 error_uri:
-	LOG(L_ERR, "ERROR: do_action: set*: uri too long\n");
+	LM_ERR("set*: uri too long\n");
 	if (new_uri) pkg_free(new_uri);
 	return E_UNSPEC;
 error_fwd_uri:
