@@ -1,5 +1,5 @@
 /* 
- * $Id: row.h 1827 2007-03-12 15:22:53Z bogdan_iancu $ 
+ * $Id: row.h 2185 2007-05-10 12:37:19Z henningw $ 
  *
  * MySQL module row related functions
  *
@@ -35,11 +35,4 @@
  */
 int db_mysql_convert_row(db_con_t* _h, db_res_t* _res, db_row_t* _r);
 
-
-/*
- * Release memory used by row
- */
-int db_mysql_free_row(db_row_t* _r);
-
-
 #endif /* ROW_H */
