@@ -1,5 +1,5 @@
 /*
- * $Id: send_publish.h 1919 2007-03-27 16:15:46Z anca_vamanu $
+ * $Id: send_publish.h 2596 2007-08-13 12:40:27Z anca_vamanu $
  *
  * pua module - presence user agent module
  *
@@ -29,7 +29,7 @@
 #include "../tm/tm_load.h"
 #include "../../str.h"
 #include "hash.h"
-
+#include "event_list.h"
 
 typedef struct publ_info
 {
@@ -39,13 +39,24 @@ typedef struct publ_info
 	int expires;
 	int flag;
 	int source_flag;
-
+	int event;   
+	str content_type;  /*the content_type of the body if present(optional if the
+					   *	 same as the default value for that event) */	 
+	str* etag;
+	str* extra_headers;
+	void* cb_param;   /* the parameter for the function to be called on the callback 
+						 for the received reply; it must be allocated in share memory;
+						 a reference to it will be found in the cb_param filed of the ua_pres_structure
+						 receied as a parameter for the registered function*/
 }publ_info_t;
 
 typedef int (*send_publish_t)(publ_info_t* publ);
 int send_publish( publ_info_t* publ );
-void print_ua_pres(ua_pres_t* p);
+
 void publ_cback_func(struct cell *t, int type, struct tmcb_params *ps);
-str* publ_build_hdr(int expires, str* etag, int is_body);
+str* publ_build_hdr(int expires, pua_event_t* event, str* content_type, str* etag,
+		str* extra_headers, int is_body);
+ua_pres_t* publish_cbparam(publ_info_t* publ, str* body, str* tuple_id,
+		int ua_flag);
 
 #endif
