@@ -1,5 +1,5 @@
 /*
- * $Id: send_subscribe.h 1827 2007-03-12 15:22:53Z bogdan_iancu $
+ * $Id: send_subscribe.h 3741 2008-02-21 16:11:11Z anca_vamanu $
  *
  * pua module - presence user agent module
  *
@@ -37,17 +37,26 @@ typedef struct subs_info
 	str id;
 	str* pres_uri;
 	str* watcher_uri;
+	str* contact;
+	str* outbound_proxy;
 	int event;
+	str* extra_headers;
 	int expires;
-	int flag;
 	int source_flag;
-
+	int flag;         /*  it can be : INSERT_TYPE or UPDATE_TYPE; not compulsory */
+	void* cb_param;  /* the parameter for the function to be called on the callback 
+						 for the received reply; it must be allocated in share memory;
+						 a reference to it will be found in the cb_param filed of the ua_pres_structure
+						 receied as a parameter for the registered function*/
 }subs_info_t;
 
+
 typedef int (*send_subscribe_t)(subs_info_t* subs);
 int send_subscribe(subs_info_t* subs);
 void subs_cback_func(struct cell *t, int type, struct tmcb_params *ps);
-str* subs_build_hdr(str* watcher_uri, int expires, int event);
+str* subs_build_hdr(str* watcher_uri, int expires, int event, str* extra_headers);
 dlg_t* pua_build_dlg_t(ua_pres_t* presentity);
+ua_pres_t* subscribe_cbparam(subs_info_t* subs, int ua_flag);
+ua_pres_t* subs_cbparam_indlg(ua_pres_t* subs, int ua_flag);
 
 #endif
