@@ -1,5 +1,5 @@
 /*
- * $Id: api.c 1827 2007-03-12 15:22:53Z bogdan_iancu $
+ * $Id: api.c 3270 2007-12-06 12:44:15Z bogdan_iancu $
  *
  * Copyright (C) 2005 Voice Sistem SRL
  *
@@ -32,6 +32,7 @@
 #include "api.h"
 #include "rr_cb.h"
 
+extern int append_fromtag;
 
 int load_rr( struct rr_binds *rrb )
 {
@@ -40,6 +41,7 @@ int load_rr( struct rr_binds *rrb )
 	rrb->is_direction      = is_direction;
 	rrb->get_route_param   = get_route_param;
 	rrb->register_rrcb     = register_rrcb;
+	rrb->append_fromtag    = append_fromtag;
 
 	return 1;
 }
