@@ -1,4 +1,4 @@
-/* $Id: seas_action.c 2210 2007-05-11 11:56:59Z henningw $
+/* $Id: seas_action.c 3069 2007-11-08 17:32:11Z miconda $
  *
  * Copyright (C) 2006-2007 VozTelecom Sistemas S.L
  *
@@ -34,6 +34,7 @@
 #include "../../ip_addr.h"
 #include "../../tags.h"
 #include "../../error.h"
+#include "../../ut.h"
 #include "../../parser/hf.h"
 #include "../../parser/parse_fline.h"
 #include "../../parser/parser_f.h"/*find_not_quoted*/
@@ -72,7 +73,6 @@ extern char seas_tags[];
 pid_t my_parent;
 extern int fifo_pid;
 
-static inline int shm_str_dup(str* _d, str* _s);
 static inline struct sip_msg *parse_ac_msg(hdr_flags_t flags,char *start,int len);
 static inline void free_sip_msg_lite(struct sip_msg *my_msg);
 static inline int calculate_hooks(dlg_t* _d);
@@ -84,7 +84,7 @@ int process_pong(struct ha *the_table,unsigned int seqno);
 int print_local_uri(as_p as,char processor_id,char *where,int len);
 
 
-int dispatch_actions()
+int dispatch_actions(void)
 {
    int fd,n,ret,timeout,elapsed_ms;
    static int ktimeout;
@@ -108,7 +108,7 @@ int dispatch_actions()
       ktimeout=servlet_ping_timeout;
    /*ac_buffer is pkg_malloc because only this process (action dispatcher) will use it*/
    if((my_as->u.as.ac_buffer.s = pkg_malloc(AS_BUF_SIZE))==0){
-      LOG(L_ERR,"unable to alloc pkg mem for the action buffer\n");
+      LM_ERR("no more pkg mem\n");
       return -1;
    }
    my_as->u.as.ac_buffer.len=0;
@@ -122,9 +122,9 @@ int dispatch_actions()
 	       gettimeofday(&last,NULL);
 	       continue;
 	    }else if(errno==EBADF){
-	       LOG(L_ERR,"EBADF !!\n");
+	       LM_ERR("EBADF !!\n");
 	    }else{
-	       LOG(L_ERR,"on poll\n");
+	       LM_ERR("on poll\n");
 	    }
 	 }else if(n==0){/*timeout*/
 	    if (0>(ret=process_pings(&my_as->u.as.jain_pings))) {
@@ -167,12 +167,12 @@ again:
    if(0>(j=read(fd,my_as->u.as.ac_buffer.s+my_as->u.as.ac_buffer.len,k))){
       if(errno==EINTR)
 	 goto again;
-      LOG(L_ERR,"reading data for as %.*s (%s)\n",my_as->name.len,my_as->name.s,strerror(errno));
+      LM_ERR("reading data for as %.*s (%s)\n",my_as->name.len,my_as->name.s,strerror(errno));
       return -1;
    }else if(j==0){
       pkg_free(my_as->u.as.ac_buffer.s);
       close(fd);
-      LOG(L_ERR,"read 0 bytes from AS:%.*s\n",my_as->name.len,my_as->name.s);
+      LM_ERR("read 0 bytes from AS:%.*s\n",my_as->name.len,my_as->name.s);
       /** we return, so we will exit, so our parent (Event Dispatcher) will receive a sigchld and know
        * it should tear down the corresponding AS
        * what still is not clear is what will happen to events that were put in the pipe...
@@ -180,12 +180,12 @@ again:
       return -2;
    }
    (my_as->u.as.ac_buffer.len)+=j;
-   LOG(L_DBG,"read %d bytes from AS action socket (total = %d)\n",j,my_as->u.as.ac_buffer.len);
+   LM_DBG("read %d bytes from AS action socket (total = %d)\n",j,my_as->u.as.ac_buffer.len);
    if(use_stats)
       receivedplus();
    if(my_as->u.as.ac_buffer.len>5){
       process_action(&my_as->u.as);
-      LOG(L_DBG,"(Action dispatched,buffer.len=%d)\n",my_as->u.as.ac_buffer.len);
+      LM_DBG("(Action dispatched,buffer.len=%d)\n",my_as->u.as.ac_buffer.len);
    }
    return 0;
 }
@@ -222,7 +222,7 @@ static inline int process_pings(struct ha *the_table)
 	 tmp=the_table->pings+k;
 	 elapsed=(now.tv_sec-tmp->sent.tv_sec)*1000+(now.tv_usec-tmp->sent.tv_usec)/1000;
 	 if(elapsed>the_table->timeout){
-	    LOG(L_DBG,"ping timed out %d\n",tmp->id);
+	    LM_DBG("ping timed out %d\n",tmp->id);
 	    the_table->timed_out_pings++;
 	 }else{
 	    the_table->begin=k;
@@ -247,18 +247,18 @@ static inline void set_process_no()
    for(i=0;i<pcnt;i++){
       if(pt[i].pid==fifo_pid){
 	 process_no=i;
-	 LOG(L_DBG,"Setting fake process_no to %d (fifo pid=%d)\n",i,fifo_pid);
+	 LM_DBG("Setting fake process_no to %d (fifo pid=%d)\n",i,fifo_pid);
 	 return;
       }
    }
    for(i=0;i<pcnt;i++){
       if(!memcmp(pt[i].desc,"unix domain socket server",26)){
 	 process_no=i;
-	 LOG(L_DBG,"Setting fake process_no to %d\n",i);
+	 LM_DBG("Setting fake process_no to %d\n",i);
 	 return;
       }
    }
-   LOG(L_ERR,"unable to fake process_no\n");
+   LM_ERR("unable to fake process_no\n");
 }
 */
 
@@ -277,35 +277,41 @@ int process_action(as_p the_as)
    if(use_stats)
       stats_reply();
    if(ac_len>AS_BUF_SIZE){
-      LOG(L_WARN,"BUG:Action too big (%d)!!! should be skipped and an error returned!\n",ac_len);
+      LM_WARN("action too big (%d)!!! should be skipped and"
+			  " an error returned!\n",ac_len);
       return -1;
    }
    while (the_as->ac_buffer.len>=ac_len) {
-      LOG(L_DBG,"Processing action %d bytes long\n",ac_len);
+      LM_DBG("Processing action %d bytes long\n",ac_len);
       switch(the_as->ac_buffer.s[4]){
 	 case REPLY_PROV:
 	 case REPLY_FIN:
-	    LOG(L_DBG,"Processing a REPLY action from AS (length=%d): %.*s\n",ac_len,the_as->name.len,the_as->name.s);
+	    LM_DBG("Processing a REPLY action from AS (length=%d): %.*s\n",
+				ac_len,the_as->name.len,the_as->name.s);
 	    ac_reply(the_as,the_as->ac_buffer.s+5,ac_len-5);
 	    break;
 	 case UAC_REQ:
-	    LOG(L_DBG,"Processing an UAC REQUEST action from AS (length=%d): %.*s\n",ac_len,the_as->name.len,the_as->name.s);
+	    LM_DBG("Processing an UAC REQUEST action from AS (length=%d): %.*s\n",
+				ac_len,the_as->name.len,the_as->name.s);
 	    ac_uac_req(the_as,the_as->ac_buffer.s+5,ac_len-5);
 	    break;
 	 case AC_CANCEL:
-	    LOG(L_DBG,"Processing a CANCEL REQUEST action from AS (length=%d): %.*s\n",ac_len,the_as->name.len,the_as->name.s);
+	    LM_DBG("Processing a CANCEL REQUEST action from AS (length=%d): %.*s\n",
+				ac_len,the_as->name.len,the_as->name.s);
 	    ac_cancel(the_as,the_as->ac_buffer.s+5,ac_len-5);
 	    break;
 	 case SL_MSG:
-	    LOG(L_DBG,"Processing a STATELESS MESSAGE action from AS (length=%d): %.*s\n",ac_len,the_as->name.len,the_as->name.s);
+	    LM_DBG("Processing a STATELESS MESSAGE action from AS (length=%d): %.*s\n",
+				ac_len,the_as->name.len,the_as->name.s);
 	    ac_sl_msg(the_as,the_as->ac_buffer.s+5,ac_len-5);
 	    break;
 	 case JAIN_PONG:
-	    LOG(L_DBG,"Processing a PONG\n");
+	    LM_DBG("Processing a PONG\n");
 	    ac_jain_pong(the_as,the_as->ac_buffer.s+5,ac_len-5);
 	    break;
 	 default:
-	    LOG(L_DBG,"Processing a UNKNOWN TYPE action from AS (length=%d): %.*s\n",ac_len,the_as->name.len,the_as->name.s);
+	    LM_DBG("Processing a UNKNOWN TYPE action from AS (length=%d): %.*s\n",
+				ac_len,the_as->name.len,the_as->name.s);
 	    break;
       }
       memmove(the_as->ac_buffer.s,the_as->ac_buffer.s+ac_len,(the_as->ac_buffer.len)-ac_len);
@@ -347,7 +353,7 @@ int process_pong(struct ha *the_table,unsigned int seqno)
       tmp=the_table->pings+k;
       if(tmp->id == seqno){
 	 elapsed=(now.tv_sec-tmp->sent.tv_sec)*1000+(now.tv_usec-tmp->sent.tv_usec)/1000;
-	 LOG(L_DBG,"Ping-Pong delay: %d (timeout was:%d)\n",elapsed,the_table->timeout);
+	 LM_DBG("Ping-Pong delay: %d (timeout was:%d)\n",elapsed,the_table->timeout);
 	 if(elapsed>the_table->timeout){
 	    /*if this ping has timed out, all the more-ancient pings will also be
 	     * timed out*/
@@ -401,54 +407,69 @@ int ac_cancel(as_p the_as,char *action,int len)
    net2hostL(cancelled_label,action,k);
 
    if(!(headers.s=pkg_malloc(MAX_HEADER))){
-      LOG(L_ERR,"Out of Memory!!");
+      LM_ERR("Out of Memory!!");
       goto error;
    }
    headers.len=0;
    if(!(my_msg=pkg_malloc(sizeof(struct sip_msg)))){
-      LOG(L_ERR,"out of memory!\n");
+      LM_ERR("out of memory!\n");
       goto error;
    }
    memset(my_msg,0,sizeof(struct sip_msg));
    my_msg->buf=action+k;
    my_msg->len=len-k;
-   LOG(L_DBG,"Action UAC Message: uac_id:%d processor_id=%d, message:[%.*s]\n",uac_id,processor_id,len-4,&action[4]);
+   LM_DBG("Action UAC Message: uac_id:%d processor_id=%d, message:[%.*s]\n",
+		   uac_id,processor_id,len-4,&action[4]);
    if(parse_msg(action+k,len-k,my_msg)<0){
-      LOG(L_ERR,"parsing sip_msg");
+      LM_ERR("parsing sip_msg");
       goto error;
    }
    if(my_msg->first_line.type==SIP_REPLY){
-      LOG(L_ERR,"trying to create a UAC with a SIP response!!\n");
+      LM_ERR("trying to create a UAC with a SIP response!!\n");
       goto error;
    }
    if(parse_headers(my_msg,HDR_EOH_F,0)==-1){
-      LOG(L_ERR,"parsing headers\n");
+      LM_ERR("parsing headers\n");
       goto error;
    }
    if(0>(headers.len=extract_allowed_headers(my_msg,1,-1,HDR_CONTENTLENGTH_F|HDR_ROUTE_F|HDR_TO_F|HDR_FROM_F|HDR_CALLID_F|HDR_CSEQ_F,headers.s,MAX_HEADER))) {
-      LOG(L_ERR,"Unable to extract allowed headers!!\n");
+      LM_ERR("Unable to extract allowed headers!!\n");
       goto error;
    }
+   if(flags & SPIRAL_FLAG){
+      memcpy(headers.s+headers.len,SPIRAL_HDR CRLF,SPIRAL_HDR_LEN + CRLF_LEN);
+      headers.len+=SPIRAL_HDR_LEN+CRLF_LEN;
+      /*headers.s[headers.len]=0;
+      fake_uri.s=pkg_malloc(200);
+      fake_uri.len=print_local_uri(the_as,processor_id,fake_uri.s,200);
+
+      if(fake_uri.len<0){
+	 SLM_ERR("printing local uri\n");
+	 goto error;
+      }
+      my_dlg->hooks.next_hop=&fake_uri;*/
+   }
+
    headers.s[headers.len]=0;
 
    /*let's get the body*/
    i=(unsigned int)get_content_length(my_msg);
    if(i!=0){
       if(!(body.s=pkg_malloc(i))){
-	 LOG(L_ERR,"Out of Memory!");
+	 LM_ERR("Out of Memory!");
 	 goto error;
       }
       memcpy(body.s,get_body(my_msg),i);
       body.len=i;
-      LOG(L_DBG,"Trying to construct a Sip Request with: body:%d[%s] headers:%d[%s]\n",\
-	    body.len,body.s,headers.len,headers.s);
+      LM_DBG("Trying to construct a Sip Request with: body:%d[%s]"
+			  " headers:%d[%s]\n", body.len,body.s,headers.len,headers.s);
    }else{
       body.s=NULL;
       body.len=0;
    }
 
    if(!(the_param=shm_malloc(sizeof(struct as_uac_param)))){
-      LOG(L_ERR,"out of shared memory\n");
+      LM_ERR("no more share memory\n");
       goto error;
    }
    the_param->who=my_as;
@@ -457,7 +478,7 @@ int ac_cancel(as_p the_as,char *action,int len)
 
    ret=seas_f.tmb.t_cancel_uac(&headers,&body,cancelled_hashIdx,cancelled_label,uac_cb,(void*)the_param);
    if (ret == 0) {
-      LOG(L_ERR, "Error on t_cancel_uac\n");
+      LM_ERR( "t_cancel_uac failed\n");
       as_action_fail_resp(uac_id,SE_CANCEL,SE_CANCEL_MSG,SE_CANCEL_MSG_LEN);
       goto error;
    }else{
@@ -543,12 +564,12 @@ int via_diff(struct sip_msg *req,struct sip_msg *resp)
    for(hf=resp->h_via1;hf;hf=hf->sibling){
       if(!hf->parsed){
 	 if((vb=pkg_malloc(sizeof(struct via_body)))==0){
-	    LOG(L_ERR,"Out of mem in via_diff!!\n");
+	    LM_ERR("Out of mem in via_diff!!\n");
 	    return -1;
 	 }
 	 memset(vb,0,sizeof(struct via_body));
 	 if(parse_via(hf->body.s,hf->body.s+hf->body.len+1,vb)==0){
-	    LOG(L_ERR,"Unable to parse via in via_diff!\n");
+	    LM_ERR("Unable to parse via in via_diff!\n");
 	    pkg_free(vb);
 	    return -1;
 	 }
@@ -621,18 +642,18 @@ int ac_reply(as_p the_as,char *action,int len)
    net2hostL(label,action,k);
 
    if(seas_f.tmb.t_lookup_ident(&c,hash_index,label)<0){
-      LOG(L_ERR,"Failed to t_lookup_ident hash_idx=%d,label=%d\n",hash_index,label);
+      LM_ERR("Failed to t_lookup_ident hash_idx=%d,label=%d\n",hash_index,label);
       goto error;
    }
    if(use_stats)
       action_stat(c);
    if(c->uas.status>=200){
-      LOG(L_ERR,"ac_reply: trying to reply to a \"%.*s\" transaction"
+      LM_ERR("ac_reply: trying to reply to a \"%.*s\" transaction"
 	    "that is already in completed state\n",REQ_LINE(c->uas.request).method.len,REQ_LINE(c->uas.request).method.s);
       goto error;
    }
    if (!(my_msg=parse_ac_msg(HDR_EOH_F,action+k,len-k))) {
-      LOG(L_ERR,"Failed to parse_ac_msg hash_idx=%d,label=%d\n",hash_index,label);
+      LM_ERR("Failed to parse_ac_msg hash_idx=%d,label=%d\n",hash_index,label);
       goto error;
    }
    tb=(struct to_body*)my_msg->to->parsed;
@@ -642,26 +663,26 @@ int ac_reply(as_p the_as,char *action,int len)
       totag.s=NULL;
       totag.len=0;
       /*if(!(ttag=pkg_malloc(TOTAG_VALUE_LEN))){
-	 LOG(L_ERR,"Out of memory !!!\n");
+	 LM_ERR("Out of memory !!!\n");
 	 goto error;
       }
       totag.s=ttag;
       calc_crc_suffix(c->uas.request,seas_tag_suffix);
-      LOG(L_DBG,"seas_tags = %.*s\n",TOTAG_VALUE_LEN,seas_tags);
+      LM_DBG("seas_tags = %.*s\n",TOTAG_VALUE_LEN,seas_tags);
       memcpy(totag.s,seas_tags,TOTAG_VALUE_LEN);
       totag.len=TOTAG_VALUE_LEN;*/
    }
-   LOG(L_DBG,"Using totag=[%.*s]\n",totag.len,totag.s);
+   LM_DBG("Using totag=[%.*s]\n",totag.len,totag.s);
    if(my_msg->content_length)
       contentlength=(unsigned int)(long)my_msg->content_length->parsed;
    if(0>(i=recordroute_diff(c->uas.request,my_msg))){/*not likely..*/
-      LOG(L_DBG,"Seems that request had more RecordRoutes than response...\n");
+      LM_DBG("Seems that request had more RecordRoutes than response...\n");
       goto error;
    }else
-      LOG(L_DBG,"Recordroute Diff = %d\n",i);
+      LM_DBG("Recordroute Diff = %d\n",i);
 
    if(0>(i=extract_allowed_headers(my_msg,0,i,HDR_VIA_F|HDR_TO_F|HDR_FROM_F|HDR_CSEQ_F|HDR_CALLID_F|HDR_CONTENTLENGTH_F,headers,MAX_HEADER))){
-      LOG(L_ERR,"ac_reply() filtering headers !\n");
+      LM_ERR("ac_reply() filtering headers !\n");
       goto error;
    }
    headers[i]=0;
@@ -677,12 +698,12 @@ int ac_reply(as_p the_as,char *action,int len)
    body.len=contentlength;
    body.s=get_body(my_msg);
 
-   LOG(L_DBG,"Trying to construct a SipReply with: ReasonPhrase:[%.*s] body:[%.*s] headers:[%.*s] totag:[%.*s]\n",\
+   LM_DBG("Trying to construct a SipReply with: ReasonPhrase:[%.*s] body:[%.*s] headers:[%.*s] totag:[%.*s]\n",\
 	 my_msg->first_line.u.reply.reason.len,my_msg->first_line.u.reply.reason.s,\
 	 body.len,body.s,new_header.len,new_header.s,totag.len,totag.s);
    /* t_reply_with_body un-ref-counts the transaction, so dont use it anymore*/
    if(seas_f.tmb.t_reply_with_body(c,my_msg->first_line.u.reply.statuscode,&(my_msg->first_line.u.reply.reason),&body,&new_header,&totag)<0){
-      LOG(L_ERR,"Failed to t_reply\n");
+      LM_ERR("Failed to t_reply\n");
       goto error;
    }
    retval=0;
@@ -704,19 +725,19 @@ static inline struct sip_msg *parse_ac_msg(hdr_flags_t flags,char *start,int len
    struct sip_msg *my_msg;
    my_msg=NULL;
    if(!(my_msg=pkg_malloc(sizeof(struct sip_msg)))){
-      LOG(L_ERR,"ac_reply: out of memory!\n");
+      LM_ERR("ac_reply: out of memory!\n");
       goto error;
    }
    memset(my_msg,0,sizeof(struct sip_msg));
    my_msg->buf=start;
    my_msg->len=len;
-   LOG(L_DBG,"Action Message:[%.*s]\n",len,start);
+   LM_DBG("Action Message:[%.*s]\n",len,start);
    if(0>parse_msg(start,len,my_msg)){
-      LOG(L_ERR,"parse_ac_msg: parsing sip_msg");
+      LM_ERR("parse_ac_msg: parsing sip_msg");
       goto error;
    }
    if(0>parse_headers(my_msg,flags,0)){
-      LOG(L_ERR,"parse_ac_msg: parsing headers\n");
+      LM_ERR("parse_ac_msg: parsing headers\n");
       goto error;
    }
    return my_msg;
@@ -755,19 +776,19 @@ int ac_sl_msg(as_p the_as,char *action,int len)
    proxy=0;
 
    if(!(my_msg = parse_ac_msg(HDR_EOH_F,action+k,len-k))){
-      LOG(L_ERR,"out of memory!\n");
+      LM_ERR("out of memory!\n");
       goto error;
    }
    if(my_msg->first_line.type == SIP_REQUEST)
-      LOG(L_DBG,"forwarding request:\"%.*s\" statelessly \n",my_msg->first_line.u.request.method.len+1+\
+      LM_DBG("forwarding request:\"%.*s\" statelessly \n",my_msg->first_line.u.request.method.len+1+\
 	    my_msg->first_line.u.request.uri.len,my_msg->first_line.u.request.method.s);
    else
-      LOG(L_DBG,"forwarding reply:\"%.*s\" statelessly \n",my_msg->first_line.u.reply.status.len+1+\
+      LM_DBG("forwarding reply:\"%.*s\" statelessly \n",my_msg->first_line.u.reply.status.len+1+\
 	    my_msg->first_line.u.reply.reason.len,my_msg->first_line.u.reply.status.s);
 
    if (my_msg->route) {
       if (parse_rr(my_msg->route) < 0) {
-	 LOG(L_ERR, "Error while parsing Route body\n");
+	 LM_ERR( "Error while parsing Route body\n");
 	 goto error;
       }
       my_route = (rr_t*)my_msg->route->parsed;
@@ -782,7 +803,7 @@ int ac_sl_msg(as_p the_as,char *action,int len)
       */
    proxy=uri2proxy(uri,PROTO_NONE);
    if (proxy==0) {
-      LOG(L_ERR,"unable to create proxy from URI \n");
+      LM_ERR("unable to create proxy from URI \n");
       goto error;
    }
    proto=proxy->proto; /* uri2proxy set it correctly */
@@ -837,14 +858,14 @@ int forward_sl_request(struct sip_msg *msg,struct proxy_l *proxy,int proto)
 	do {
 		send_sock=get_send_socket(msg, to, proto);
 		if (send_sock==0){
-			LOG(L_ERR, "ERROR:seas:forward_msg: cannot forward to af %d, "
+			LM_ERR( "ERROR:seas:forward_msg: cannot forward to af %d, "
 				"proto %d no corresponding listening socket\n",
 				to->s.sa_family, proto);
 			continue;
 		}
 		DBG("seas:sl_msg:Sending:\n%.*s.\n", (int)msg->len,msg->buf);
 		if (msg_send(send_sock, proto, to, 0, msg->buf,msg->len)<0){
-			LOG(L_ERR,"ERROR:seas:forward_msg: Error sending message !!\n");
+			LM_ERR("ERROR:seas:forward_msg: Error sending message !!\n");
 			continue;
 		}
 		ret = 0;
@@ -892,43 +913,43 @@ int ac_uac_req(as_p the_as,char *action,int len)
    processor_id=action[k++];
 
    if(!(headers.s=pkg_malloc(MAX_HEADER))){
-      LOG(L_ERR,"Out of Memory!!");
+      LM_ERR("Out of Memory!!");
       goto error;
    }
    headers.len=0;
-   LOG(L_DBG,"Action UAC Message: uac_id:%d processor_id=%d\n",uac_id,processor_id);
+   LM_DBG("Action UAC Message: uac_id:%d processor_id=%d\n",uac_id,processor_id);
    if (!(my_msg = parse_ac_msg(HDR_EOH_F,action+k,len-k))) {
-      LOG(L_ERR,"out of memory!\n");
+      LM_ERR("out of memory!\n");
       goto error;
    }
    if(my_msg->first_line.type==SIP_REPLY){
-      LOG(L_ERR,"trying to create a UAC with a SIP response!!\n");
+      LM_ERR("trying to create a UAC with a SIP response!!\n");
       goto error;
    }
    if(parse_headers(my_msg,HDR_EOH_F,0)==-1){
-      LOG(L_ERR,"ERROR:seas:ac_uac_req:parsing headers\n");
+      LM_ERR("ERROR:seas:ac_uac_req:parsing headers\n");
       goto error;
    }
    if(parse_from_header(my_msg)<0){
-      LOG(L_ERR,"parsing from header ! \n");
+      LM_ERR("parsing from header ! \n");
       goto error;
    }
    if(check_transaction_quadruple(my_msg)==0){
       as_action_fail_resp(uac_id,SE_UAC,"Headers missing (to,from,call-id,cseq)?",0);
-      LOG(L_ERR,"Headers missing (to,from,call-id,cseq)?");
+      LM_ERR("Headers missing (to,from,call-id,cseq)?");
       goto error;
    }
    if(!(get_from(my_msg)) || !(get_from(my_msg)->tag_value.s) || 
 	 !(get_from(my_msg)->tag_value.len)){
       as_action_fail_resp(uac_id,SE_UAC,"From tag missing",0);
-      LOG(L_ERR,"From tag missing");
+      LM_ERR("From tag missing");
       goto error;
    }
    fb=my_msg->from->parsed;
    tb=my_msg->to->parsed;
    cseqb=my_msg->cseq->parsed;
    if(0!=(str2int(&cseqb->number,&cseq))){
-      LOG(L_DBG,"unable to parse CSeq\n");
+      LM_DBG("unable to parse CSeq\n");
       goto error;
    }
    if(my_msg->first_line.u.request.method_value != METHOD_ACK &&
@@ -939,7 +960,7 @@ int ac_uac_req(as_p the_as,char *action,int len)
    if(seas_f.tmb.new_dlg_uac(&(my_msg->callid->body),&(fb->tag_value),cseq,\
 	    &(fb->uri),&(tb->uri),&my_dlg) < 0) {
       as_action_fail_resp(uac_id,SE_UAC,"Error creating new dialog",0);
-      LOG(L_ERR,"Error while creating new dialog\n");
+      LM_ERR("Error while creating new dialog\n");
       goto error;
    }
    if(tb->tag_value.s && tb->tag_value.len)
@@ -952,7 +973,7 @@ int ac_uac_req(as_p the_as,char *action,int len)
    server_signature=0;
    my_dlg->state = DLG_CONFIRMED;
    if(0>(headers.len=extract_allowed_headers(my_msg,1,-1,HDR_CONTENTLENGTH_F|HDR_ROUTE_F|HDR_TO_F|HDR_FROM_F|HDR_CALLID_F|HDR_CSEQ_F,headers.s,MAX_HEADER))) {
-      LOG(L_ERR,"Unable to extract allowed headers!!\n");
+      LM_ERR("Unable to extract allowed headers!!\n");
       goto error;
    }
    headers.s[headers.len]=0;
@@ -961,13 +982,13 @@ int ac_uac_req(as_p the_as,char *action,int len)
       clen=(long)get_content_length(my_msg);
    if(clen!=0){
       if(!(body.s=pkg_malloc(clen))){
-	 LOG(L_ERR,"Out of Memory!");
+	 LM_ERR("Out of Memory!");
 	 goto error;
       }
       memcpy(body.s,get_body(my_msg),clen);
       body.len=clen;
       body.s[clen]=0;
-      LOG(L_DBG,"Trying to construct a Sip Request with: body:%d[%.*s] headers:%d[%.*s]\n",\
+      LM_DBG("Trying to construct a Sip Request with: body:%d[%.*s] headers:%d[%.*s]\n",\
 	    body.len,body.len,body.s,headers.len,headers.len,headers.s);
       /*t_reply_with_body un-ref-counts the transaction, so dont use it anymore*/
    }else{
@@ -985,7 +1006,7 @@ int ac_uac_req(as_p the_as,char *action,int len)
     *
     */
    if(!(the_param=shm_malloc(sizeof(struct as_uac_param)))){
-      LOG(L_ERR,"out of shared memory\n");
+      LM_ERR("out of shared memory\n");
       goto error;
    }
    the_param->who=my_as;
@@ -996,7 +1017,7 @@ int ac_uac_req(as_p the_as,char *action,int len)
 
    if (my_msg->route) {
       if (parse_rr(my_msg->route) < 0) {
-	 LOG(L_ERR, "Error while parsing Route body\n");
+	 LM_ERR( "Error while parsing Route body\n");
 	 goto error;
       }
       /* TODO route_set should be a shm copy of my_msg->route->parsed */
@@ -1015,7 +1036,7 @@ int ac_uac_req(as_p the_as,char *action,int len)
       fake_uri.len=print_local_uri(the_as,processor_id,fake_uri.s,200);
 
       if(fake_uri.len<0){
-	 LOG(L_ERR,"printing local uri\n");
+	 LM_ERR("printing local uri\n");
 	 goto error;
       }
       my_dlg->hooks.next_hop=&fake_uri;
@@ -1027,7 +1048,7 @@ int ac_uac_req(as_p the_as,char *action,int len)
    my_dlg->route_set=(rr_t *)0;
    if (ret <= 0) {
       err_ret = err2reason_phrase(ret,&sip_error,err_buf, sizeof(err_buf), "SEAS/UAC");
-      LOG(L_ERR,"Error on request_within %s\n",err_buf );
+      LM_ERR("Error on request_within %s\n",err_buf );
       if(err_ret > 0) {
 	 as_action_fail_resp(uac_id,ret,err_buf,0);
       }else{
@@ -1072,7 +1093,7 @@ int print_local_uri(as_p as,char processor_id,char *where,int len)
 	 break;
    }
    if(i==MAX_BINDS){
-      LOG(L_DBG,"processor ID not found\n");
+      LM_DBG("processor ID not found\n");
       return -1;
    }
    si=as->binds[i];
@@ -1105,14 +1126,14 @@ int print_local_uri(as_p as,char processor_id,char *where,int len)
 	       htons(si->address.u.addr16[6]), htons(si->address.u.addr16[7]),si->port_no,proto.len,proto.s);
 	 break;
       default:
-	 LOG(L_ERR,"address family unknown\n");
+	 LM_ERR("address family unknown\n");
 	 return -1;
    }
    if(i>len){
-      LOG(L_ERR,"Output was truncated!!\n");
+      LM_ERR("Output was truncated!!\n");
       return -1;
    }else if(i<0){
-      LOG(L_ERR,"Error on snprintf\n");
+      LM_ERR("Error on snprintf\n");
       return i;
    }
    return i;
@@ -1151,23 +1172,15 @@ static inline int calculate_hooks(dlg_t* _d)
 {
    str* uri;
    struct sip_uri puri;
-   param_hooks_t hooks;
-   param_t* params;
 
    if (_d->route_set) {
       uri = &_d->route_set->nameaddr.uri;
       if (parse_uri(uri->s, uri->len, &puri) < 0) {
-         LOG(L_ERR, "Error while parsing URI\n");
+         LM_ERR( "Error while parsing URI\n");
          return -1;
       }
 
-      if (parse_params(&puri.params, CLASS_URI, &hooks, &params) < 0) {
-         LOG(L_ERR, "Error while parsing parameters\n");
-         return -2;
-      }
-      free_params(params);
-
-      if (hooks.uri.lr) {
+      if (puri.lr.s) {
          if (_d->rem_target.s) _d->hooks.request_uri = &_d->rem_target;
          else _d->hooks.request_uri = &_d->rem_uri;
 	 _d->hooks.next_hop = &_d->route_set->nameaddr.uri;
@@ -1219,13 +1232,13 @@ int extract_allowed_headers(struct sip_msg *my_msg,int strip_top_vias,int allow_
 
    for(hf=my_msg->headers;hf;hf=hf->next){
       if(forbidden_hdrs & HDR_T2F(hf->type)){
-	 LOG(L_DBG,"Skipping header (%.*s)\n",hf->name.len,hf->name.s);
+	 LM_DBG("Skipping header (%.*s)\n",hf->name.len,hf->name.s);
 	 continue;
       }else if(hf->type==HDR_VIA_T && strip_top_vias > 0){
 	 /** All vias MUST be parsed !!*/
 	 for(i=0,vb=hf->parsed;vb;vb=vb->next,i++);
 	 if(i<=strip_top_vias){
-	    LOG(L_DBG,"Stripping vias [%.*s]\n",hf->len,hf->name.s);
+	    LM_DBG("Stripping vias [%.*s]\n",hf->len,hf->name.s);
 	    /** skip this via header*/
 	    strip_top_vias-=i;
 	 }else{
@@ -1234,7 +1247,7 @@ int extract_allowed_headers(struct sip_msg *my_msg,int strip_top_vias,int allow_
 	    while(strip_top_vias--)
 	       vb=vb->next;
 	    k= (hf->name.s + hf->len) - vb->name.s;
-	    LOG(L_DBG,"Stripping vias [%.*s]\n",(int)(vb->name.s-hf->name.s),
+	    LM_DBG("Stripping vias [%.*s]\n",(int)(vb->name.s-hf->name.s),
 		  hf->name.s);
 	    if(k+VIA_LEN<headers_len){
 	       memcpy(headers+len,VIA,VIA_LEN);
@@ -1242,7 +1255,7 @@ int extract_allowed_headers(struct sip_msg *my_msg,int strip_top_vias,int allow_
 	       memcpy(headers+len,vb->name.s,k);
 	       len+=k;
 	    }else{
-	       LOG(L_ERR,"Out Of Space !!\n");
+	       LM_ERR("Out Of Space !!\n");
 	       goto error;
 	    }
 	 }
@@ -1250,17 +1263,17 @@ int extract_allowed_headers(struct sip_msg *my_msg,int strip_top_vias,int allow_
 	 if(rtcnt==0)
 	    continue;
 	 if(!hf->parsed && 0>parse_rr(hf)){
-	    LOG(L_ERR,"parsing Record-Route:\"%.*s\"\n",hf->body.len,hf->body.s);
+	    LM_ERR("parsing Record-Route:\"%.*s\"\n",hf->body.len,hf->body.s);
 	    goto error;
 	 }
 	 for(i=0,rb=hf->parsed;rb;rb=rb->next,i++);
 	 if(i<=rtcnt){
 	    if((len+hf->len)<headers_len){
-	       LOG(L_DBG,"Allowing RecordRoute [%.*s]\n",hf->len,hf->name.s);
+	       LM_DBG("Allowing RecordRoute [%.*s]\n",hf->len,hf->name.s);
 	       memcpy(headers+len,hf->name.s,hf->len);
 	       len+=hf->len;
 	    }else{
-	       LOG(L_ERR,"Unable to keep recordroute (not enough space left in headers) Discarding \"%.*s\" \n",hf->name.len,hf->name.s);
+	       LM_ERR("Unable to keep recordroute (not enough space left in headers) Discarding \"%.*s\" \n",hf->name.len,hf->name.s);
 	       goto error;
 	    }
 	    /** is this dangerous ? because the rtcnt is the control variable for this conditional 'if'
@@ -1274,12 +1287,12 @@ int extract_allowed_headers(struct sip_msg *my_msg,int strip_top_vias,int allow_
 	    k= (((rb->nameaddr.name.s) + rb->len)-hf->name.s) ;
 	    if(len+k+CRLF_LEN<headers_len){
 	       memcpy(headers+len,hf->name.s,k);
-	       LOG(L_DBG,"Allowing RecordRoute [%.*s\r\n]\n",k,hf->name.s);
+	       LM_DBG("Allowing RecordRoute [%.*s\r\n]\n",k,hf->name.s);
 	       len+=k;
 	       memcpy(headers+len,CRLF,CRLF_LEN);
 	       len+=CRLF_LEN;
 	    }else{
-	       LOG(L_ERR,"Out Of Space !!\n");
+	       LM_ERR("Out Of Space !!\n");
 	       goto error;
 	    }
 	 }
@@ -1292,7 +1305,8 @@ int extract_allowed_headers(struct sip_msg *my_msg,int strip_top_vias,int allow_
 	    memcpy(headers+len,hf->name.s,hf->len);
 	    len+=hf->len;
 	 }else{
-	    LOG(L_WARN,"Too many headers. Discarding \"%.*s\" \n",hf->name.len,hf->name.s);
+	    LM_WARN("Too many headers. Discarding \"%.*s\" \n",
+				hf->name.len,hf->name.s);
 	 }
       }
    }/*for*/
@@ -1302,23 +1316,6 @@ error:
 }
 
 
-/*
- * Make a copy of a str structure using shm_malloc
- */
-static inline int shm_str_dup(str* _d, str* _s)
-{
-   _d->s = shm_malloc(_s->len);
-   if (!_d->s) {
-      LOG(L_ERR, "No memory left\n");
-      return -1;
-   }
-
-   memcpy(_d->s, _s->s, _s->len);
-   _d->len = _s->len;
-   return 0;
-}
-
-
 /**
  * ERROR action responses are composed of:
  * 4: the length of the event
@@ -1337,7 +1334,7 @@ int as_action_fail_resp(int uac_id,int sip_error,char *err_buf,int i)
    if(i==0)
       i=strlen(err_buf);
    if(i>MAX_REASON_LEN){
-      LOG(L_ERR,"Error Reason bigger than MAX_REASON_LEN\n");
+      LM_ERR("Error Reason bigger than MAX_REASON_LEN\n");
       return -1;
    }
    msg[k++]=AC_RES_FAIL;
@@ -1382,16 +1379,18 @@ void uac_cb(struct cell* t, int type,struct tmcb_params *rcvd_params)
    if(!ev_info || !ev_info->who){
       return;
    }
-   LOG(L_DBG,"Reply to UAC Transaction for AS:%.*s code: %d\n",ev_info->who->name.len,ev_info->who->name.s,code);
-   LOG(L_DBG,"Transaction %p Nr_of_outgoings:%d is_Local:%c\n",t,t->nr_of_outgoings,is_local(t)?'y':'n');
+   LM_DBG("reply to UAC Transaction for AS:%.*s code: %d\n",
+		   ev_info->who->name.len,ev_info->who->name.s,code);
+   LM_DBG("transaction %p Nr_of_outgoings:%d is_Local:%c\n",
+		   t,t->nr_of_outgoings,is_local(t)?'y':'n');
    for(i=0;i<t->nr_of_outgoings;i++)
-      LOG(L_DBG,"UAC[%d].last_received=%d\n",i,t->uac[i].last_received);
+      LM_DBG("UAC[%d].last_received=%d\n",i,t->uac[i].last_received);
    if(!(my_as_ev=shm_malloc(sizeof(as_msg_t)))){
-      LOG(L_ERR,"Out of shared mem\n");
+      LM_ERR("no more shared mem\n");
       goto error;
    }
    if(!(buffer=create_as_action_reply(t,rcvd_params,ev_info->uac_id,ev_info->processor_id,&mylen))){
-      LOG(L_ERR,":seas:uac_cb() Unable to encode message\n");
+      LM_ERR("failed to encode message\n");
       goto error;
    }
    my_as_ev->as = ev_info->who;
@@ -1422,7 +1421,7 @@ char* create_as_action_reply(struct cell *c,struct tmcb_params *params,int uac_i
    char *buffer;
    struct sip_msg *msg;
    if(!(buffer=shm_malloc(ENCODED_MSG_SIZE))){
-      LOG(L_ERR,"create_as_action_reply Out Of Memory !!\n");
+      LM_ERR("create_as_action_reply Out Of Memory !!\n");
       return 0;
    }
    msg=0;
@@ -1497,7 +1496,7 @@ char* create_as_action_reply(struct cell *c,struct tmcb_params *params,int uac_i
    /*length of event (hdr+payload-4), copied at the beginning*/
    if(params->rpl != FAKED_REPLY) {
       if((i=encode_msg(msg,buffer+k,ENCODED_MSG_SIZE-k))<0){
-	 LOG(L_ERR,"Unable to encode msg\n");
+	 LM_ERR("failed to encode msg\n");
 	 goto error;
       }
       k+=i;
