@@ -1,5 +1,5 @@
 /*
- * $Id: dlg.c 1827 2007-03-12 15:22:53Z bogdan_iancu $
+ * $Id: dlg.c 3296 2007-12-10 12:30:18Z bogdan_iancu $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -75,24 +75,6 @@ void get_raw_uri(str* _s)
 }
 
 
-
-/*
- * Make a copy of a str structure using shm_malloc
- */
-static inline int str_duplicate(str* _d, str* _s)
-{
-	_d->s = shm_malloc(_s->len);
-	if (!_d->s) {
-		LOG(L_ERR, "str_duplicate(): No memory left\n");
-		return -1;
-	}
-	
-	memcpy(_d->s, _s->s, _s->len);
-	_d->len = _s->len;
-	return 0;
-}
-
-
 /*
  * Calculate dialog hooks
  */
@@ -100,23 +82,15 @@ static inline int calculate_hooks(dlg_t* _d)
 {
 	str* uri;
 	struct sip_uri puri;
-	param_hooks_t hooks;
-	param_t* params;
 
 	if (_d->route_set) {
 		uri = &_d->route_set->nameaddr.uri;
 		if (parse_uri(uri->s, uri->len, &puri) < 0) {
-			LOG(L_ERR, "calculate_hooks(): Error while parsing URI\n");
+			LM_ERR("failed parse to URI\n");
 			return -1;
 		}
 
-		if (parse_params(&puri.params, CLASS_URI, &hooks, &params) < 0) {
-			LOG(L_ERR, "calculate_hooks(): Error while parsing parameters\n");
-			return -2;
-		}
-		free_params(params);
-		
-		if (hooks.uri.lr) {
+		if (puri.lr.s) {
 			if (_d->rem_target.s) _d->hooks.request_uri = &_d->rem_target;
 			else _d->hooks.request_uri = &_d->rem_uri;
 			_d->hooks.next_hop = &_d->route_set->nameaddr.uri;
@@ -130,7 +104,8 @@ static inline int calculate_hooks(dlg_t* _d)
 	} else {
 		if (_d->rem_target.s) _d->hooks.request_uri = &_d->rem_target;
 		else _d->hooks.request_uri = &_d->rem_uri;
-		_d->hooks.next_hop = _d->hooks.request_uri;
+		if(_d->hooks.next_hop==NULL)
+			_d->hooks.next_hop = _d->hooks.request_uri;
 	}
 
 	if ((_d->hooks.request_uri) && (_d->hooks.request_uri->s) && (_d->hooks.request_uri->len)) {
@@ -166,13 +141,13 @@ int new_dlg_uac(str* _cid, str* _ltag, unsigned int _lseq, str* _luri, str* _rur
 	dlg_t* res;
 
 	if (!_cid || !_ltag || !_luri || !_ruri || !_d) {
-		LOG(L_ERR, "new_dlg_uac(): Invalid parameter value\n");
+		LM_ERR("Invalid parameter value\n");
 		return -1;
 	}
 
 	res = (dlg_t*)shm_malloc(sizeof(dlg_t));
 	if (res == 0) {
-		LOG(L_ERR, "new_dlg_uac(): No memory left\n");
+		LM_ERR("No memory left\n");
 		return -2;
 	}
 
@@ -180,13 +155,13 @@ int new_dlg_uac(str* _cid, str* _ltag, unsigned int _lseq, str* _luri, str* _rur
 	memset(res, 0, sizeof(dlg_t));
 	
 	     /* Make a copy of Call-ID */
-	if (str_duplicate(&res->id.call_id, _cid) < 0) return -3;
+	if (shm_str_dup(&res->id.call_id, _cid) < 0) return -3;
 	     /* Make a copy of local tag (usually From tag) */
-	if (str_duplicate(&res->id.loc_tag, _ltag) < 0) return -4;
+	if (shm_str_dup(&res->id.loc_tag, _ltag) < 0) return -4;
 	     /* Make a copy of local URI (usually From) */
-	if (str_duplicate(&res->loc_uri, _luri) < 0) return -5;
+	if (shm_str_dup(&res->loc_uri, _luri) < 0) return -5;
 	     /* Make a copy of remote URI (usually To) */
-	if (str_duplicate(&res->rem_uri, _ruri) < 0) return -6;
+	if (shm_str_dup(&res->rem_uri, _ruri) < 0) return -6;
 	     /* Make a copy of local sequence (usually CSeq) */
 	res->loc_seq.value = _lseq;
 	     /* And mark it as set */
@@ -195,7 +170,7 @@ int new_dlg_uac(str* _cid, str* _ltag, unsigned int _lseq, str* _luri, str* _rur
 	*_d = res;
 
 	if (calculate_hooks(*_d) < 0) {
-		LOG(L_ERR, "new_dlg_uac(): Error while calculating hooks\n");
+		LM_ERR("failed to calculate hooks\n");
 		/* FIXME: free everything here */
 		shm_free(res);
 		return -2;
@@ -218,14 +193,14 @@ static inline int get_contact_uri(struct sip_msg* _m, str* _uri)
 	if (!_m->contact) return 1;
 
 	if (parse_contact(_m->contact) < 0) {
-		LOG(L_ERR, "get_contact_uri(): Error while parsing Contact body\n");
+		LM_ERR("failed to parse Contact body\n");
 		return -2;
 	}
 
 	c = ((contact_body_t*)_m->contact->parsed)->contacts;
 
 	if (!c) {
-		LOG(L_ERR, "get_contact_uri(): Empty body or * contact\n");
+		LM_ERR("Empty body or * contact\n");
 		return -3;
 	}
 
@@ -242,7 +217,7 @@ static inline int get_contact_uri(struct sip_msg* _m, str* _uri)
 static inline int get_to_tag(struct sip_msg* _m, str* _tag)
 {
 	if (!_m->to) {
-		LOG(L_ERR, "get_to_tag(): To header field missing\n");
+		LM_ERR("To header field missing\n");
 		return -1;
 	}
 
@@ -263,7 +238,7 @@ static inline int get_to_tag(struct sip_msg* _m, str* _tag)
 static inline int get_from_tag(struct sip_msg* _m, str* _tag)
 {
 	if (parse_from_header(_m)<0) {
-		LOG(L_ERR, "get_from_tag(): Error while parsing From header\n");
+		LM_ERR("failed to parse From header\n");
 		return -1;
 	}
 
@@ -285,7 +260,7 @@ static inline int get_from_tag(struct sip_msg* _m, str* _tag)
 static inline int get_callid(struct sip_msg* _m, str* _cid)
 {
 	if (_m->callid == 0) {
-		LOG(L_ERR, "get_callid(): Call-ID not found\n");
+		LM_ERR("Call-ID not found\n");
 		return -1;
 	}
 
@@ -305,19 +280,20 @@ static inline int get_route_set(struct sip_msg* _m, rr_t** _rs, unsigned char _o
 	rr_t* last, *p, *t;
 	
 	last = 0;
+	*_rs = 0;
 
 	ptr = _m->record_route;
 	while(ptr) {
 		if (ptr->type == HDR_RECORDROUTE_T) {
 			if (parse_rr(ptr) < 0) {
-				LOG(L_ERR, "get_route_set(): Error while parsing Record-Route body\n");
+				LM_ERR("failed to parse Record-Route body\n");
 				goto error;
 			}
 
 			p = (rr_t*)ptr->parsed;
 			while(p) {
-				if (shm_duplicate_rr(&t, p) < 0) {
-					LOG(L_ERR, "get_route_set(): Error while duplicating rr_t\n");
+				if (shm_duplicate_rr(&t, p, 1/*only first*/) < 0) {
+					LM_ERR("duplicating rr_t\n");
 					goto error;
 				}
 				if (_order == NORMAL_ORDER) {
@@ -354,15 +330,15 @@ static inline int response2dlg(struct sip_msg* _m, dlg_t* _d)
 
 	     /* Parse the whole message, we will need all Record-Route headers */
 	if (parse_headers(_m, HDR_EOH_F, 0) == -1) {
-		LOG(L_ERR, "response2dlg(): Error while parsing headers\n");
+		LM_ERR("failed to parse headers\n");
 		return -1;
 	}
 	
 	if (get_contact_uri(_m, &contact) < 0) return -2;
-	if (contact.len && str_duplicate(&_d->rem_target, &contact) < 0) return -3;
+	if (contact.len && shm_str_dup(&_d->rem_target, &contact) < 0) return -3;
 	
 	if (get_to_tag(_m, &rtag) < 0) goto err1;
-	if (rtag.len && str_duplicate(&_d->id.rem_tag, &rtag) < 0) goto err1;
+	if (rtag.len && shm_str_dup(&_d->id.rem_tag, &rtag) < 0) goto err1;
 	
 	if (get_route_set(_m, &_d->route_set, REVERSE_ORDER) < 0) goto err2;
 
@@ -411,7 +387,7 @@ static inline int dlg_new_resp_uac(dlg_t* _d, struct sip_msg* _m)
 		_d->state = DLG_CONFIRMED;
 
 		if (calculate_hooks(_d) < 0) {
-			LOG(L_ERR, "dlg_new_resp_uac(): Error while calculating hooks\n");
+			LM_ERR("failed to calculate hooks\n");
 			return -2;
 		}
 	} else {
@@ -451,7 +427,7 @@ static inline int dlg_early_resp_uac(dlg_t* _d, struct sip_msg* _m)
 		_d->state = DLG_CONFIRMED;
 
 		if (calculate_hooks(_d) < 0) {
-			LOG(L_ERR, "dlg_early_resp_uac(): Error while calculating hooks\n");
+			LM_ERR("failed to calculate hooks\n");
 			return -2;
 		}
 	} else {
@@ -471,7 +447,7 @@ static inline int dlg_early_resp_uac(dlg_t* _d, struct sip_msg* _m)
 static inline int get_cseq_method(struct sip_msg* _m, str* _method)
 {
 	if (!_m->cseq && ((parse_headers(_m, HDR_CSEQ_F, 0)==-1) || !_m->cseq)) {
-		LOG(L_ERR, "get_cseq_method(): Error while parsing CSeq\n");
+		LM_ERR("failed to parse CSeq\n");
 		return -1;
 	}
 
@@ -490,7 +466,7 @@ static inline int dlg_confirmed_resp_uac(dlg_t* _d, struct sip_msg* _m)
 	int code;
 	str method, contact;
 
-	code = _m->first_line.u.reply.statuscode;	
+	code = _m->first_line.u.reply.statuscode;
 
 	     /* Dialog has been already confirmed, that means we received
 	      * a response to a request sent within the dialog. We will
@@ -512,25 +488,25 @@ static inline int dlg_confirmed_resp_uac(dlg_t* _d, struct sip_msg* _m)
 		return 1;
 	}
 
-	     /* Do nothing if not 2xx */
+	/* Do nothing if not 2xx */
 	if ((code < 200) || (code >= 300)) return 0;
-	
+
 	if (get_cseq_method(_m, &method) < 0) return -1;
 	if ((method.len == 6) && !memcmp("INVITE", method.s, 6)) {
-		     /* Get contact if any and update remote target */
+		/* Get contact if any and update remote target */
 		if (parse_headers(_m, HDR_CONTACT_F, 0) == -1) {
-			LOG(L_ERR, "dlg_confirmed_resp_uac(): Error while parsing headers\n");
+			LM_ERR("failed to parse headers\n");
 			return -2;
 		}
 
-		     /* Try to extract contact URI */
+		/* Try to extract contact URI */
 		if (get_contact_uri(_m, &contact) < 0) return -3;
-		     /* If there is a contact URI */
+		/* If there is a contact URI */
 		if (contact.len) {
-			     /* Free old remote target if any */
+			/* Free old remote target if any */
 			if (_d->rem_target.s) shm_free(_d->rem_target.s);
-			     /* Duplicate new remote target */
-			if (str_duplicate(&_d->rem_target, &contact) < 0) return -4;
+			/* Duplicate new remote target */
+			if (shm_str_dup(&_d->rem_target, &contact) < 0) return -4;
 		}
 	}
 
@@ -544,27 +520,27 @@ static inline int dlg_confirmed_resp_uac(dlg_t* _d, struct sip_msg* _m)
 int dlg_response_uac(dlg_t* _d, struct sip_msg* _m)
 {
 	if (!_d || !_m) {
-		LOG(L_ERR, "dlg_response_uac(): Invalid parameter value\n");
+		LM_ERR("invalid parameter value\n");
 		return -1;
 	}
 
-	     /* The main dispatcher */
+	/* The main dispatcher */
 	switch(_d->state) {
-	case DLG_NEW:       
+	case DLG_NEW:
 		return dlg_new_resp_uac(_d, _m);
 
-	case DLG_EARLY:     
+	case DLG_EARLY:
 		return dlg_early_resp_uac(_d, _m);
 
-	case DLG_CONFIRMED: 
+	case DLG_CONFIRMED:
 		return dlg_confirmed_resp_uac(_d, _m);
 
 	case DLG_DESTROYED:
-		LOG(L_ERR, "dlg_response_uac(): Cannot handle destroyed dialog\n");
+		LM_ERR("failed handle destroyed dialog\n");
 		return -2;
 	}
 
-	LOG(L_ERR, "dlg_response_uac(): Error in switch statement\n");
+	LM_ERR("unsuccessful switch statement\n");
 	return -3;
 }
 
@@ -578,7 +554,7 @@ static inline int get_cseq_value(struct sip_msg* _m, unsigned int* _cs)
 	str num;
 
 	if (_m->cseq == 0) {
-		LOG(L_ERR, "get_cseq_value(): CSeq header not found\n");
+		LM_ERR("CSeq header not found\n");
 		return -1;
 	}
 
@@ -587,7 +563,7 @@ static inline int get_cseq_value(struct sip_msg* _m, unsigned int* _cs)
 
 	trim_leading(&num);
 	if (str2int(&num, _cs) < 0) {
-		LOG(L_ERR, "get_cseq_value(): Error while converting cseq number\n");
+		LM_ERR("converting cseq number failed\n");
 		return -2;
 	}
 	return 0;
@@ -605,7 +581,7 @@ static inline int get_dlg_uri(struct hdr_field* _h, str* _s)
 	int tag_len = 0, len;
 
 	if (!_h) {
-		LOG(L_ERR, "get_dlg_uri(): Header field not found\n");
+		LM_ERR("header field not found\n");
 		return -1;
 	}
 
@@ -640,7 +616,7 @@ static inline int get_dlg_uri(struct hdr_field* _h, str* _s)
 
 	_s->s = shm_malloc(_h->body.len - tag_len);
 	if (!_s->s) {
-		LOG(L_ERR, "get_dlg_uri(): No memory left\n");
+		LM_ERR("No share memory left\n");
 		return -1;
 	}
 
@@ -667,18 +643,18 @@ static inline int request2dlg(struct sip_msg* _m, dlg_t* _d)
 	str contact, rtag, callid;
 
 	if (parse_headers(_m, HDR_EOH_F, 0) == -1) {
-		LOG(L_ERR, "request2dlg(): Error while parsing headers");
+		LM_ERR("failed to parse headers");
 		return -1;
 	}
 
 	if (get_contact_uri(_m, &contact) < 0) return -2;
-	if (contact.len && str_duplicate(&_d->rem_target, &contact) < 0) return -3;
+	if (contact.len && shm_str_dup(&_d->rem_target, &contact) < 0) return -3;
 	
 	if (get_from_tag(_m, &rtag) < 0) goto err1;
-	if (rtag.len && str_duplicate(&_d->id.rem_tag, &rtag) < 0) goto err1;
+	if (rtag.len && shm_str_dup(&_d->id.rem_tag, &rtag) < 0) goto err1;
 
 	if (get_callid(_m, &callid) < 0) goto err2;
-	if (callid.len && str_duplicate(&_d->id.call_id, &callid) < 0) goto err2;
+	if (callid.len && shm_str_dup(&_d->id.call_id, &callid) < 0) goto err2;
 
 	if (get_cseq_value(_m, &_d->rem_seq.value) < 0) goto err3;
 	_d->rem_seq.is_set = 1;
@@ -722,32 +698,32 @@ int new_dlg_uas(struct sip_msg* _req, int _code, /*str* _tag,*/ dlg_t** _d)
 	str tag;
 
 	if (!_req || /*!_tag ||*/ !_d) {
-		LOG(L_ERR, "new_dlg_uas(): Invalid parameter value\n");
+		LM_ERR("Invalid parameter value\n");
 		return -1;
 	}
 
 	if ((_code < 200) || (_code > 299)) {
-		DBG("new_dlg_uas(): Not a 2xx, no dialog created\n");
+		LM_DBG("not a 2xx, no dialog created\n");
 		return -2;
 	}
 
 	res = (dlg_t*)shm_malloc(sizeof(dlg_t));
 	if (res == 0) {
-		LOG(L_ERR, "new_dlg_uac(): No memory left\n");
+		LM_ERR("no more share memory\n");
 		return -3;
 	}
 	     /* Clear everything */
 	memset(res, 0, sizeof(dlg_t));	
 
 	if (request2dlg(_req, res) < 0) {
-		LOG(L_ERR, "new_dlg_uas(): Error while converting request to dialog\n");
+		LM_ERR("converting request to dialog failed\n");
 		return -4;
 	}
 
 	tag.s = tm_tags;
 	tag.len = TOTAG_VALUE_LEN;
 	calc_crc_suffix(_req, tm_tag_suffix);
-	if (str_duplicate(&res->id.loc_tag, &tag) < 0) {
+	if (shm_str_dup(&res->id.loc_tag, &tag) < 0) {
 		free_dlg(res);
 		return -5;
 	}
@@ -756,7 +732,7 @@ int new_dlg_uas(struct sip_msg* _req, int _code, /*str* _tag,*/ dlg_t** _d)
 
 	(*_d)->state = DLG_CONFIRMED;
 	if (calculate_hooks(*_d) < 0) {
-		LOG(L_ERR, "new_dlg_uas(): Error while calculating hooks\n");
+		LM_ERR("calculating hooks failed\n");
 		shm_free(*_d);
 		return -6;
 	}
@@ -774,7 +750,7 @@ int dlg_request_uas(dlg_t* _d, struct sip_msg* _m)
 	unsigned int cseq;
 
 	if (!_d || !_m) {
-		LOG(L_ERR, "dlg_request_uas(): Invalid parameter value\n");
+		LM_ERR("Invalid parameter value\n");
 		return -1;
 	}
 
@@ -782,7 +758,7 @@ int dlg_request_uas(dlg_t* _d, struct sip_msg* _m)
 	      * first, if so then we will not update anything
 	      */
 	if (parse_headers(_m, HDR_CSEQ_F, 0) == -1) {
-		LOG(L_ERR, "dlg_request_uas(): Error while parsing headers\n");
+		LM_ERR("parsing headers failed\n");
 		return -2;
 	}
 	if (get_cseq_value(_m, &cseq) < 0) return -3;
@@ -798,14 +774,14 @@ int dlg_request_uas(dlg_t* _d, struct sip_msg* _m)
 	if (_m->first_line.u.request.method_value == METHOD_INVITE) {
 		     /* target refresher */
 		if (parse_headers(_m, HDR_CONTACT_F, 0) == -1) {
-			LOG(L_ERR, "dlg_request_uas(): Error while parsing headers\n");
+			LM_ERR("parsing headers failed\n");
 			return -4;
 		}
 		
 		if (get_contact_uri(_m, &contact) < 0) return -5;
 		if (contact.len) {
 			if (_d->rem_target.s) shm_free(_d->rem_target.s);
-			if (str_duplicate(&_d->rem_target, &contact) < 0) return -6;
+			if (shm_str_dup(&_d->rem_target, &contact) < 0) return -6;
 		}
 	}
 
