@@ -1,5 +1,5 @@
 /*
- * $Id: t_msgbuilder.c 1827 2007-03-12 15:22:53Z bogdan_iancu $
+ * $Id: t_msgbuilder.c 3298 2007-12-10 17:01:46Z bogdan_iancu $
  *
  * message printing
  *
@@ -52,6 +52,9 @@
 #define ROUTE_SEPARATOR ", "
 #define ROUTE_SEPARATOR_LEN (sizeof(ROUTE_SEPARATOR) - 1)
 
+#define LOCAL_MAXFWD_HEADER "Max-Forwards: " LOCAL_MAXFWD_VALUE CRLF
+#define LOCAL_MAXFWD_HEADER_LEN (sizeof(LOCAL_MAXFWD_HEADER) - 1)
+
 /* convenience macros */
 #define  append_string(_d,_s,_len) \
 	do{\
@@ -63,7 +66,7 @@
 #define SET_FOUND(_new_state) \
 	do{\
 		fill->s=b;fill->len=p-b;\
-		DBG("DEBUG:tm:extract_hdrs: hdr %d extracted as <%.*s>\n",\
+		LM_DBG("hdr %d extracted as <%.*s>\n",\
 			flag,fill->len,fill->s);\
 		flags&=~(flag);\
 		if (flags) {state=_new_state;}\
@@ -170,14 +173,46 @@ static int extract_hdrs( char *buf, int len, str *from, str *to, str *cseq)
 		p++;
 	}
 
-	LOG(L_CRIT,"BUG:tm:extract_hdrs: no hdrs found in outgoing buffer\n");
+	LM_CRIT("no hdrs found in outgoing buffer\n");
 	return -1;
 done:
 	return 0;
 }
 
 
-/* Build a local request based on a previous request; main
+static inline struct hdr_field* extract_parsed_hdrs( char *buf, int len)
+{
+	char *p;
+	static struct sip_msg msg;
+	struct hdr_field  *hdr;
+
+	LM_DBG("----parsing the buf req - first line\n");
+	/* skip the first line - not interesting */
+	p = eat_line( buf, len);
+	if (p>=buf+len)
+		return 0;
+
+	memset( &msg, 0, sizeof(struct sip_msg) );
+	msg.buf = buf;
+	msg.len = len;
+	msg.unparsed = p;
+
+	/* as we need all Route headers, we need to parse all headers */
+	if (parse_headers( &msg, HDR_EOH_F, 0)==-1)
+		goto error;
+
+	hdr = msg.headers;
+	msg.headers = 0;
+
+	free_sip_msg( &msg );
+	return hdr;
+error:
+	free_sip_msg( &msg );
+	return 0;
+}
+
+
+/* Build a local request based on a previous request; the only
    customers of this function are local ACK and local CANCEL
  */
 char *build_local(struct cell *Trans,unsigned int branch,
@@ -185,6 +220,7 @@ char *build_local(struct cell *Trans,unsigned int branch,
 {
 	char                *cancel_buf, *p, *via;
 	unsigned int         via_len;
+	struct hdr_field    *buf_hdrs;
 	struct hdr_field    *hdr;
 	struct sip_msg      *req;
 	char branch_buf[MAX_BRANCH_PARAM_LEN];
@@ -198,6 +234,7 @@ char *build_local(struct cell *Trans,unsigned int branch,
 	from = Trans->from;
 	cseq_n = Trans->cseq_n;
 	to = *uas_to;
+	buf_hdrs = 0;
 
 	if (req && req->msg_flags&(FL_USE_UAC_FROM|FL_USE_UAC_TO|FL_USE_UAC_CSEQ)) {
 		if ( extract_hdrs( Trans->uac[branch].request.buffer.s,
@@ -205,12 +242,11 @@ char *build_local(struct cell *Trans,unsigned int branch,
 		(req->msg_flags&FL_USE_UAC_FROM)?&from:0 ,
 		(req->msg_flags&FL_USE_UAC_TO)?&to:0 ,
 		(req->msg_flags&FL_USE_UAC_CSEQ)?&cseq_n:0 )!=0 ) {
-			LOG(L_ERR, "ERROR:tm:build_local: "
-				"failed to extract UAC hdrs\n");
+			LM_ERR("build_local: failed to extract UAC hdrs\n");
 			goto error;
 		}
 	}
-	DBG("DEBUG:tm:build_local: using FROM=<%.*s>, TO=<%.*s>, CSEQ_N=<%.*s>\n",
+	LM_DBG("using FROM=<%.*s>, TO=<%.*s>, CSEQ_N=<%.*s>\n",
 		from.len,from.s , to.len,to.s , cseq_n.len,cseq_n.s);
 
 	/* method, separators, version  */
@@ -224,37 +260,39 @@ char *build_local(struct cell *Trans,unsigned int branch,
 	set_hostport(&hp, (is_local(Trans))?0:req);
 	via=via_builder(&via_len, Trans->uac[branch].request.dst.send_sock,
 		&branch_str, 0, Trans->uac[branch].request.dst.proto, &hp );
-	if (!via)
-	{
-		LOG(L_ERR, "ERROR: build_local: "
-			"no via header got from builder\n");
+	if (!via){
+		LM_ERR("no via header got from builder\n");
 		goto error;
 	}
 	*len+= via_len;
 	/*headers*/
 	*len+=from.len+Trans->callid.len+to.len+cseq_n.len+1+method_len+CRLF_LEN;
 
-	/* copy'n'paste Route headers */
-	if (!is_local(Trans)) {
-		for ( hdr=req->headers ; hdr ; hdr=hdr->next )
-			 if (hdr->type==HDR_ROUTE_T)
+	/* copy'n'paste Route headers that were sent out */
+	if (!is_local(Trans) && req && req->route) {
+		buf_hdrs = extract_parsed_hdrs(Trans->uac[branch].request.buffer.s,
+			Trans->uac[branch].request.buffer.len );
+		if (buf_hdrs==NULL) {
+			LM_ERR("failed to reparse the request buffer\n");
+			goto error01;
+		}
+		for ( hdr=buf_hdrs ; hdr ; hdr=hdr->next )
+			if (hdr->type==HDR_ROUTE_T)
 				*len+=hdr->len;
-		if (Trans->uac[branch].path_vec.len)
-			*len+=Trans->uac[branch].path_vec.len+ROUTE_PREFIX_LEN+CRLF_LEN;
 	}
 
 	/* User Agent */
 	if (server_signature) {
 		*len += user_agent_header.len + CRLF_LEN;
 	}
-	/* Content Length, EoM */
-	*len+=CONTENT_LENGTH_LEN+1 + CRLF_LEN + CRLF_LEN;
+	/* Content Length, MaxFwd, EoM */
+	*len+=LOCAL_MAXFWD_HEADER_LEN + CONTENT_LENGTH_LEN+1 + CRLF_LEN + CRLF_LEN;
 
 	cancel_buf=shm_malloc( *len+1 );
 	if (!cancel_buf)
 	{
-		LOG(L_ERR, "ERROR: build_local: cannot allocate memory\n");
-		goto error01;
+		LM_ERR("no more share memory\n");
+		goto error02;
 	}
 	p = cancel_buf;
 
@@ -274,22 +312,14 @@ char *build_local(struct cell *Trans,unsigned int branch,
 	append_string( p, cseq_n.s, cseq_n.len );
 	*(p++) = ' ';
 	append_string( p, method, method_len );
-	append_string( p, CRLF, CRLF_LEN );
+	append_string( p, CRLF LOCAL_MAXFWD_HEADER,
+		CRLF_LEN+LOCAL_MAXFWD_HEADER_LEN );
 
-	if (!is_local(Trans))  {
-		/* Path */
-		if (Trans->uac[branch].path_vec.len) {
-			append_string(p, ROUTE_PREFIX, ROUTE_PREFIX_LEN);
-			append_string(p, Trans->uac[branch].path_vec.s,
-				Trans->uac[branch].path_vec.len);
-			append_string(p, CRLF, CRLF_LEN);
+	/* add Route hdrs (if any) */
+	for ( hdr=buf_hdrs ; hdr ; hdr=hdr->next )
+		if(hdr->type==HDR_ROUTE_T) {
+			append_string(p, hdr->name.s, hdr->len );
 		}
-		/* Route hdrs */
-		for ( hdr=req->headers ; hdr ; hdr=hdr->next )
-			if(hdr->type==HDR_ROUTE_T) {
-				append_string(p, hdr->name.s, hdr->len );
-			}
-	}
 
 	/* User Agent header, Content Length, EoM */
 	if (server_signature) {
@@ -304,6 +334,8 @@ char *build_local(struct cell *Trans,unsigned int branch,
 
 	pkg_free(via);
 	return cancel_buf;
+error02:
+	free_hdr_field_lst(buf_hdrs);
 error01:
 	pkg_free(via);
 error:
@@ -341,7 +373,7 @@ static inline int process_routeset(struct sip_msg* msg, str* contact, struct rte
 	while(ptr) {
 		if (ptr->type == HDR_RECORDROUTE_T) {
 			if (parse_rr(ptr) < 0) {
-				LOG(L_ERR, "process_routeset: Error while parsing Record-Route header\n");
+				LM_ERR("failed to parse Record-Route header\n");
 				return -1;
 			}
 			
@@ -349,7 +381,7 @@ static inline int process_routeset(struct sip_msg* msg, str* contact, struct rte
 			while(p) {
 				t = (struct rte*)pkg_malloc(sizeof(struct rte));
 				if (!t) {
-					LOG(L_ERR, "process_routeset: No memory left\n");
+					LM_ERR("no more pkg memory\n");
 					free_rte_list(head);
 					return -1;
 				}
@@ -364,7 +396,7 @@ static inline int process_routeset(struct sip_msg* msg, str* contact, struct rte
 	
 	if (head) {
 		if (parse_uri(head->ptr->nameaddr.uri.s, head->ptr->nameaddr.uri.len, &puri) < 0) {
-			LOG(L_ERR, "process_routeset: Error while parsing URI\n");
+			LM_ERR("failed to parse URI\n");
 			free_rte_list(head);
 			return -1;
 		}
@@ -468,14 +500,14 @@ static inline int get_contact_uri(struct sip_msg* msg, str* uri)
 	if (!msg->contact) return 1;
 	
 	if (parse_contact(msg->contact) < 0) {
-		LOG(L_ERR, "get_contact_uri: Error while parsing Contact body\n");
+		LM_ERR("failed to parse Contact body\n");
 		return -1;
 	}
 	
 	c = ((contact_body_t*)msg->contact->parsed)->contacts;
 	
 	if (!c) {
-		LOG(L_ERR, "get_contact_uri: Empty body or * contact\n");
+		LM_ERR("body or * contact\n");
 		return -2;
 	}
 	
@@ -549,7 +581,7 @@ char *build_dlg_ack(struct sip_msg* rpl, struct cell *Trans,
 	via = via_builder(&via_len, send_sock, &branch_str, 0, 
 			send_sock->proto, &hp);
 	if (!via) {
-		LOG(L_ERR, "build_dlg_ack: No via header got from builder\n");
+		LM_ERR("no via header got from builder\n");
 		goto error;
 	}
 	*len+= via_len;
@@ -570,7 +602,7 @@ char *build_dlg_ack(struct sip_msg* rpl, struct cell *Trans,
 
 	req_buf = shm_malloc(*len + 1);
 	if (!req_buf) {
-		LOG(L_ERR, "build_dlg_ack: Cannot allocate memory\n");
+		LM_ERR("no more share memory\n");
 		goto error01;
 	}
 	p = req_buf;
@@ -663,7 +695,7 @@ static inline int assemble_via(str* dest, struct cell* t, struct socket_info* so
 	struct hostport hp;
 
 	if (!t_calc_branch(t, branch, branch_buf, &len)) {
-		LOG(L_ERR, "ERROR: assemble_via: branch calculation failed\n");
+		LM_ERR("branch calculation failed\n");
 		return -1;
 	}
 	
@@ -677,7 +709,7 @@ static inline int assemble_via(str* dest, struct cell* t, struct socket_info* so
 	set_hostport(&hp, 0);
 	via = via_builder(&via_len, sock, &branch_str, 0, sock->proto, &hp);
 	if (!via) {
-		LOG(L_ERR, "assemble_via: via building failed\n");
+		LM_ERR("via building failed\n");
 		return -2;
 	}
 	
@@ -700,7 +732,7 @@ static inline char* print_request_uri(char* w, str* method, dlg_t* dialog, struc
 
 	append_string(w, dialog->hooks.request_uri->s, dialog->hooks.request_uri->len); 
 	append_string(w, " " SIP_VERSION CRLF, 1 + SIP_VERSION_LEN + CRLF_LEN);
-	DBG("print_request_uri: %.*s\n",dialog->hooks.request_uri->len, dialog->hooks.request_uri->s );
+	LM_DBG("%.*s\n",dialog->hooks.request_uri->len, dialog->hooks.request_uri->s );
 	return w;
 }
 
@@ -804,22 +836,22 @@ char* build_uac_req(str* method, str* headers, str* body, dlg_t* dialog,
 	str content_length, cseq, via;
 
 	if (!method || !dialog) {
-		LOG(L_ERR, "build_uac_req(): Invalid parameter value\n");
+		LM_ERR("inalid parameter value\n");
 		return 0;
 	}
 	if (print_content_length(&content_length, body) < 0) {
-		LOG(L_ERR, "build_uac_req(): Error while printing content-length\n");
+		LM_ERR("failed to print content-length\n");
 		return 0;
 	}
 	if (print_cseq_num(&cseq, dialog) < 0) {
-		LOG(L_ERR, "build_uac_req(): Error while printing CSeq number\n");
+		LM_ERR("failed to print CSeq number\n");
 		return 0;
 	}
 	*len = method->len + 1 + dialog->hooks.request_uri->len + 1 + 
 		SIP_VERSION_LEN + CRLF_LEN;
 
 	if (assemble_via(&via, t, dialog->send_sock, branch) < 0) {
-		LOG(L_ERR, "build_uac_req(): Error while assembling Via\n");
+		LM_ERR("failed to assemble Via\n");
 		return 0;
 	}
 	*len += via.len;
@@ -851,7 +883,7 @@ char* build_uac_req(str* method, str* headers, str* body, dlg_t* dialog,
 
 	buf = shm_malloc(*len + 1);
 	if (!buf) {
-		LOG(L_ERR, "build_uac_req(): no shmem\n");
+		LM_ERR("no more share memory\n");
 		goto error;
 	}
 	
@@ -916,21 +948,20 @@ char *build_uac_cancel(str *headers,str *body,struct cell *cancelledT,
 	struct hostport hp;
 	str content_length;
 
-	DBG("DEBUG:tm:build_uac_cancel: using FROM=<%.*s>, TO=<%.*s>, "
-		"CSEQ_N=<%.*s>\n", cancelledT->from.len, cancelledT->from.s,
-		 cancelledT->to.len, cancelledT->to.s, cancelledT->cseq_n.len,
-		 cancelledT->cseq_n.s);
+	LM_DBG("sing FROM=<%.*s>, TO=<%.*s>, CSEQ_N=<%.*s>\n",
+		cancelledT->from.len, cancelledT->from.s, cancelledT->to.len,
+		cancelledT->to.s, cancelledT->cseq_n.len, cancelledT->cseq_n.s);
 
 	branch_str.s=branch_buf;
 	if (!t_calc_branch(cancelledT,  branch, branch_str.s, &branch_str.len )){
-		LOG(L_ERR, "ERROR: build_uac_cancel: unable to create branch !\n");
+		LM_ERR("failed to create branch !\n");
 		goto error;
 	}
 	set_hostport(&hp,0);
 	via=via_builder(&via_len, cancelledT->uac[branch].request.dst.send_sock,
 			&branch_str, 0, cancelledT->uac[branch].request.dst.proto, &hp );
 	if (!via){
-		LOG(L_ERR,"ERROR: build_uac_cancel: no via header got from builder\n");
+		LM_ERR("no via header got from builder\n");
 		goto error;
 	}
 
@@ -953,8 +984,7 @@ char *build_uac_cancel(str *headers,str *body,struct cell *cancelledT,
 	}
 	/* Content Length  */
 	if (print_content_length(&content_length, body) < 0) {
-		LOG(L_ERR, "ERROR:build_uac_cancel(): Error while printing "
-			"content-length\n");
+		LM_ERR("failed to print content-length\n");
 		return 0;
 	}
 	/* Content-Length */
@@ -969,7 +999,7 @@ char *build_uac_cancel(str *headers,str *body,struct cell *cancelledT,
 	cancel_buf=shm_malloc( *len+1 );
 	if (!cancel_buf)
 	{
-		LOG(L_ERR, "ERROR: build_uac_cancel: cannot allocate memory\n");
+		LM_ERR("no more share memory\n");
 		goto error01;
 	}
 	p = cancel_buf;
