@@ -1,5 +1,5 @@
 /*
- * $Id: t_reply.c 2159 2007-05-07 12:20:10Z bogdan_iancu $
+ * $Id: t_reply.c 3907 2008-03-10 14:12:12Z bogdan_iancu $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -78,7 +78,6 @@
 #include "../../data_lump.h"
 #include "../../data_lump_rpl.h"
 #include "../../usr_avp.h"
-#include "../../unixsock_server.h"
 
 #include "h_table.h"
 #include "t_hooks.h"
@@ -111,7 +110,7 @@ static int goto_on_reply=0;
 
 
 /* returns the picked branch */
-int t_get_picked_branch()
+int t_get_picked_branch(void)
 {
 	return picked_branch;
 }
@@ -155,16 +154,16 @@ void t_on_reply( unsigned int go_to )
 }
 
 
-unsigned int get_on_negative()
+unsigned int get_on_negative(void)
 {
 	return goto_on_negative;
 }
-unsigned int get_on_reply()
+unsigned int get_on_reply(void)
 {
 	return goto_on_reply;
 }
 
-void tm_init_tags()
+void tm_init_tags(void)
 {
 	init_tags(tm_tags, &tm_tag_suffix, 
 		"OpenSER-TM/tags", TM_TAG_SEPARATOR );
@@ -180,14 +179,14 @@ int unmatched_totag(struct cell *t, struct sip_msg *ack)
 
 	if (parse_headers(ack, HDR_TO_F,0)==-1 || 
 				!ack->to ) {
-		LOG(L_ERR, "ERROR: unmatched_totag: To invalid\n");
+		LM_ERR("To invalid\n");
 		return 1;
 	}
 	tag=&get_to(ack)->tag_value;
 	for (i=t->fwded_totags; i; i=i->next) {
 		if (i->tag.len==tag->len
 				&& memcmp(i->tag.s, tag->s, tag->len)==0) {
-			DBG("DEBUG: totag for e2e ACK found: %d\n", i->acked);
+			LM_DBG("totag for e2e ACK found: %d\n", i->acked);
 			/* to-tag recorded, and an ACK has been received for it */
 			if (i->acked) return 0;
 			/* to-tag recorded, but this ACK came for the first time */
@@ -222,12 +221,12 @@ inline static int update_totag_set(struct cell *t, struct sip_msg *ok)
 	char *s;
 
 	if (!ok->to || !ok->to->parsed) {
-		LOG(L_ERR, "ERROR: update_totag_set: to not parsed\n");
+		LM_ERR("to not parsed\n");
 		return 0;
 	}
 	tag=&get_to(ok)->tag_value;
 	if (!tag->s) {
-		DBG("ERROR: update_totag_set: no tag in to\n");
+		LM_DBG("no tag in to\n");
 		return 0;
 	}
 
@@ -236,9 +235,9 @@ inline static int update_totag_set(struct cell *t, struct sip_msg *ok)
 				&& memcmp(i->tag.s, tag->s, tag->len) ==0 ){
 			/* to tag already recorded */
 #ifdef XL_DEBUG
-			LOG(L_CRIT, "DEBUG: update_totag_set: totag retransmission\n");
+			LM_CRIT("totag retransmission\n");
 #else
-			DBG("DEBUG: update_totag_set: totag retransmission\n");
+			LM_DBG("totag retransmission\n");
 #endif
 			return 1;
 		}
@@ -249,7 +248,7 @@ inline static int update_totag_set(struct cell *t, struct sip_msg *ok)
 	s=(char *)shm_malloc_unsafe(tag->len);
 	shm_unlock();
 	if (!s || !n) {
-		LOG(L_ERR, "ERROR: update_totag_set: no  memory \n");
+		LM_ERR("no more share memory \n");
 		if (n) shm_free(n);
 		if (s) shm_free(s);
 		return 0;
@@ -259,7 +258,7 @@ inline static int update_totag_set(struct cell *t, struct sip_msg *ok)
 	n->tag.s=s;n->tag.len=tag->len;
 	n->next=t->fwded_totags;
 	t->fwded_totags=n;
-	DBG("DEBUG: update_totag_set: new totag \n");
+	LM_DBG("new totag \n");
 	return 0;
 }
 
@@ -275,8 +274,7 @@ static int send_ack(struct sip_msg* rpl, struct cell *trans, int branch)
 
 	if (parse_headers( rpl, is_local(trans)?HDR_EOH_F:HDR_TO_F, 0)==-1
 	|| !rpl->to ) {
-		LOG(L_ERR, "ERROR:tm:send_ack: "
-			"cannot generate a HBH ACK if key HFs in reply missing\n");
+		LM_ERR("failed to generate a HBH ACK if key HFs in reply missing\n");
 		goto error;
 	}
 	to.s=rpl->to->name.s;
@@ -286,7 +284,7 @@ static int send_ack(struct sip_msg* rpl, struct cell *trans, int branch)
 		build_dlg_ack(rpl, trans, branch, &to, &ack_len):
 		build_local( trans, branch, &ack_len, ACK, ACK_LEN, &to );
 	if (ack_p==0) {
-		LOG(L_ERR, "ERROR:tm:send_ack: failed to build ACK\n");
+		LM_ERR("failed to build ACK\n");
 		goto error;
 	}
 
@@ -310,7 +308,7 @@ static int _reply_light( struct cell *trans, char* buf, unsigned int len,
 
 	if (!buf)
 	{
-		DBG("DEBUG:tm:_reply_light: response building failed\n");
+		LM_DBG("response building failed\n");
 		/* determine if there are some branches to be canceled */
 		if ( is_invite(trans) ) {
 			if (lock) LOCK_REPLIES( trans );
@@ -325,8 +323,8 @@ static int _reply_light( struct cell *trans, char* buf, unsigned int len,
 	if (lock) LOCK_REPLIES( trans );
 	if ( is_invite(trans) ) which_cancel(trans, &cancel_bitmap );
 	if (trans->uas.status>=200) {
-		LOG( L_ERR, "ERROR:tm: _reply_light: can't generate %d reply"
-			" when a final %d was sent out\n", code, trans->uas.status);
+		LM_ERR("failed to generate %d reply when a final %d was sent out\n",
+				code, trans->uas.status);
 		goto error2;
 	}
 
@@ -339,7 +337,7 @@ static int _reply_light( struct cell *trans, char* buf, unsigned int len,
 	rb->buffer.s = (char*)shm_resize( rb->buffer.s, buf_len );
 	/* puts the reply's buffer to uas.response */
 	if (! rb->buffer.s ) {
-			LOG(L_ERR,"ERROR:tm:_reply_light: cannot allocate shmem buffer\n");
+			LM_ERR("failed to allocate shmem buffer\n");
 			goto error3;
 	}
 	update_local_tags(trans, bm, rb->buffer.s, buf);
@@ -356,7 +354,7 @@ static int _reply_light( struct cell *trans, char* buf, unsigned int len,
 	   a final answer whereas there are pending UACs */
 	if (code>=200) {
 		if ( is_local(trans) ) {
-			DBG("DEBUG:tm:_reply_light: local transaction completed\n");
+			LM_DBG("local transaction completed\n");
 			if ( has_tran_tmcbs(trans, TMCB_LOCAL_COMPLETED) ) {
 				run_trans_callbacks( TMCB_LOCAL_COMPLETED, trans,
 					0, FAKED_REPLY, code);
@@ -381,14 +379,14 @@ static int _reply_light( struct cell *trans, char* buf, unsigned int len,
 	/* send it out : response.dst.send_sock is valid all the time now, 
 	 * as it's taken from original request -bogdan */
 	if (!trans->uas.response.dst.send_sock) {
-		LOG(L_CRIT,"BUG:tm:_reply_light: send_sock is NULL\n");
+		LM_CRIT("send_sock is NULL\n");
 	}
 	SEND_PR_BUFFER( rb, buf, len );
-	DBG("DEBUG:tm:_reply_light: reply sent out. buf=%p: %.9s..., "
+	LM_DBG("reply sent out. buf=%p: %.9s..., "
 		"shmem=%p: %.9s\n", buf, buf, rb->buffer.s, rb->buffer.s );
 	pkg_free( buf ) ;
 	stats_trans_rpl( code, 1 /*local*/ );
-	DBG("DEBUG:tm:_reply_light: finished\n");
+	LM_DBG("finished\n");
 	return 1;
 
 error3:
@@ -501,7 +499,7 @@ static inline int fake_req(struct sip_msg *faked_req, struct sip_msg *shm_msg,
 	/* new_uri can change -- make a private copy */
 	faked_req->new_uri.s=pkg_malloc( uac->uri.len+1 );
 	if (!faked_req->new_uri.s) {
-		LOG(L_ERR, "ERROR:tm:fake_req: no uri/pkg mem\n");
+		LM_ERR("no uri/pkg mem\n");
 		goto error;
 	}
 	faked_req->new_uri.len = uac->uri.len;
@@ -522,10 +520,9 @@ error:
 	return 0;
 }
 
+
 inline static void free_faked_req(struct sip_msg *faked_req, struct cell *t)
 {
-	struct hdr_field *hdr;
-
 	if (faked_req->new_uri.s) {
 		pkg_free(faked_req->new_uri.s);
 		faked_req->new_uri.s = 0;
@@ -536,19 +533,7 @@ inline static void free_faked_req(struct sip_msg *faked_req, struct cell *t)
 	del_notflaged_lumps( &(faked_req->body_lumps), LUMPFLAG_SHMEM );
 	del_nonshm_lump_rpl( &(faked_req->reply_lump) );
 
-	/* free header's parsed structures that were added by failure handlers */
-	for( hdr=faked_req->headers ; hdr ; hdr=hdr->next ) {
-		if ( hdr->parsed && hdr_allocs_parse(hdr) &&
-		(hdr->parsed<(void*)t->uas.request ||
-		hdr->parsed>=(void*)t->uas.end_request)) {
-			/* header parsed filed doesn't point inside uas.request memory
-			 * chunck -> it was added by failure funcs.-> free it as pkg */
-			DBG("DBG:free_faked_req: removing hdr->parsed %d\n",
-					hdr->type);
-			clean_hdr_field(hdr);
-			hdr->parsed = 0;
-		}
-	}
+	clean_msg_clone( faked_req, t->uas.request, t->uas.end_request);
 }
 
 
@@ -565,22 +550,20 @@ static inline int run_failure_handlers(struct cell *t)
 
 	/* failure_route for a local UAC? */
 	if (!shmem_msg || REQ_LINE(shmem_msg).method_value==METHOD_CANCEL ) {
-		LOG(L_WARN,"WARNING:tm:run_failure_handlers: no UAC or CANCEL "
-			"support (%d, %d) \n", t->on_negative, t->tmcb_hl.reg_types);
+		LM_WARN("no UAC or CANCEL support (%d, %d) \n",
+				t->on_negative, t->tmcb_hl.reg_types);
 		return 0;
 	}
 
 	/* don't start faking anything if we don't have to */
 	if ( !has_tran_tmcbs( t, TMCB_ON_FAILURE) && !t->on_negative ) {
-		LOG(L_WARN, 
-			"Warning: run_failure_handlers: no negative handler (%d, %d)\n",
-			t->on_negative, 
+		LM_WARN("no negative handler (%d, %d)\n",t->on_negative, 
 			t->tmcb_hl.reg_types);
 		return 1;
 	}
 
 	if (!fake_req(&faked_req, shmem_msg, &t->uas, uac)) {
-		LOG(L_ERR, "ERROR: run_failure_handlers: fake_req failed\n");
+		LM_ERR("fake_req failed\n");
 		return 0;
 	}
 	/* fake also the env. conforming to the fake msg */
@@ -613,6 +596,35 @@ static inline int run_failure_handlers(struct cell *t)
 }
 
 
+static inline int is_3263_failure(struct cell *t)
+{
+	struct hdr_field *hdr; 
+	/* is is a DNS failover scenario? - according to RFC 3263
+	 * and RFC 3261, this means 503 reply with Retr-After hdr 
+	 * or timeout with no reply */
+	LM_DBG("dns-failover test: branch=%d, last_recv=%d, flags=%X\n",
+		picked_branch, t->uac[picked_branch].last_received,
+		t->uac[picked_branch].flags);
+
+	switch (t->uac[picked_branch].last_received) {
+		case 408:
+			return ((t->uac[picked_branch].flags&T_UAC_HAS_RECV_REPLY)==0);
+		case 503:
+			if (t->uac[picked_branch].reply==NULL ||
+			t->uac[picked_branch].reply==FAKED_REPLY)
+				return 0;
+			/* is the Retry-After header present (if present,
+			 * it should be already parsed) */
+			hdr = t->uac[picked_branch].reply->headers;
+			for( ; hdr ; hdr=hdr->next)
+				if (hdr->type==HDR_RETRY_AFTER_T)
+					return 1;
+			return 0;
+	}
+	return 0;
+}
+
+
 static inline int do_dns_failover(struct cell *t)
 {
 	static struct sip_msg faked_req;
@@ -627,10 +639,10 @@ static inline int do_dns_failover(struct cell *t)
 	if ( get_next_su( uac->proxy, &uac->request.dst.to, 1)!=0 )
 		return -1;
 
-	DBG("DEBUG:tm:do_dns_failover: new destination available\n");
+	LM_DBG("new destination available\n");
 
 	if (!fake_req(&faked_req, shmem_msg, &t->uas, uac)) {
-		LOG(L_ERR, "ERROR:tm:do_dns_failover: fake_req failed\n");
+		LM_ERR("fake_req failed\n");
 		return -1;
 	}
 	/* fake also the env. conforming to the fake msg */
@@ -663,22 +675,26 @@ static inline int t_pick_branch( struct cell *t, int *res_code)
 	int cancelled;
 
 	lowest_b=-1; lowest_s=999;
-	cancelled = (t->flags&T_WAS_CANCELLED_FLAG);
+	cancelled = was_cancelled(t);
 	for ( b=t->first_branch; b<t->nr_of_outgoings ; b++ ) {
 		/* skip 'empty branches' */
 		if (!t->uac[b].request.buffer.s) continue;
 		/* there is still an unfinished UAC transaction; wait now! */
 		if ( t->uac[b].last_received<200 ) 
 			return -2;
-		/* replyes to cancel has max priority */
-		if ( (cancelled && t->uac[b].last_received==487) ||
-		(t->uac[b].last_received<lowest_s && (lowest_s!=487 || !cancelled))) {
+		/* replys to cancel has max priority
+		 * 503 has minimum priority */
+		if ( (lowest_b==-1) ||
+		(cancelled && t->uac[b].last_received==487) ||
+		( (lowest_s!=487 || !cancelled) && (
+			(lowest_s==503) || (t->uac[b].last_received!=503
+			&& t->uac[b].last_received<lowest_s)
+		))) {
 			lowest_b =b;
 			lowest_s = t->uac[b].last_received;
 		}
 	} /* find lowest branch */
-	DBG("DEBUG:tm:t_pick_branch: picked branch %d, code %d\n",
-		lowest_b,lowest_s);
+	LM_DBG("picked branch %d, code %d\n",lowest_b,lowest_s);
 
 	*res_code=lowest_s;
 	return lowest_b;
@@ -710,14 +726,12 @@ static enum rps t_should_relay_response( struct cell *Trans , int new_code,
 	   >= 300 are not relayed because 200 was already sent
 	   out
 	*/
-	DBG("DEBUG:tm:t_should_relay_response: T_code=%d, new_code=%d\n",
-		Trans->uas.status,new_code);
+	LM_DBG("T_code=%d, new_code=%d\n", Trans->uas.status,new_code);
 	inv_through=new_code>=200 && new_code<300 && is_invite(Trans);
 	/* if final response sent out, allow only INVITE 2xx  */
 	if ( Trans->uas.status >= 200 ) {
 		if (inv_through) {
-			DBG("DEBUG:tm:t_should_relay_response: 200 OK for INVITE "
-				"after final sent\n");
+			LM_DBG("200 OK for INVITE after final sent\n");
 			*should_store=0;
 			Trans->uac[branch].last_received=new_code;
 			*should_relay=branch;
@@ -740,26 +754,22 @@ static enum rps t_should_relay_response( struct cell *Trans , int new_code,
 #ifdef EXTRA_DEBUG
 		/* don't report on retransmissions */
 		if (Trans->uac[branch].last_received==new_code) {
-			DBG("DEBUG:tm:t_should_relay_response: final reply "
-				"retransmission\n");
+			LM_DBG("final reply retransmission\n");
 		} else
 		/* if you FR-timed-out, faked a local 408 and 487 came, don't
 		 * report on it either */
 		if (Trans->uac[branch].last_received==408 && new_code==487) {
-			DBG("DEBUG:tm:t_should_relay_response: 487 reply came for a "
-				"timed-out branch\n");
+			LM_DBG("487 reply came for a timed-out branch\n");
 		} else {
 		/* this looks however how a very strange status rewrite attempt;
 		 * report on it */
-			DBG("DEBUG:tm:t_should_relay_response: status rewrite by UAS: "
-				"stored: %d, received: %d\n",
+			LM_DBG("status rewrite by UAS: stored: %d, received: %d\n",
 				Trans->uac[branch].last_received, new_code );
 		}
 #endif
 		goto discard;
 	}
 
-
 	/* no final response sent yet */
 	/* negative replies subject to fork picking */
 	if (new_code >=300 ) {
@@ -770,20 +780,27 @@ static enum rps t_should_relay_response( struct cell *Trans , int new_code,
 		 * save of the final reply per branch */
 		Trans->uac[branch].reply = reply;
 
-		/* if all_final return lowest */
-		picked_branch = t_pick_branch( Trans, &picked_code);
-		if (picked_branch==-2) { /* branches open yet */
-			*should_store=1;
-			*should_relay=-1;
-			picked_branch=-1;
-			Trans->uac[branch].reply = 0;
-			return RPS_STORE;
-		}
-		if (picked_branch==-1) {
-			LOG(L_CRIT, "ERROR:tm:t_should_relay_response: pick_branch failed "
-				"(lowest==-1) for code %d\n",new_code);
-			Trans->uac[branch].reply = 0;
-			goto discard;
+		if (new_code>=600) {
+			/* this is a winner and close all branches */
+			which_cancel( Trans, cancel_bitmap );
+			picked_branch=branch;
+			/* no more new branches should be added to this transaction */
+			Trans->flags |= T_NO_NEW_BRANCHES_FLAG;
+		} else {
+			/* if all_final return lowest */
+			picked_branch = t_pick_branch( Trans, &picked_code);
+			if (picked_branch==-2) { /* branches open yet */
+				*should_store=1;
+				*should_relay=-1;
+				picked_branch=-1;
+				Trans->uac[branch].reply = 0;
+				return RPS_STORE;
+			}
+			if (picked_branch==-1) {
+				LM_CRIT("pick_branch failed (lowest==-1) for code %d\n",new_code);
+				Trans->uac[branch].reply = 0;
+				goto discard;
+			}
 		}
 
 		/* no more pending branches -- try if that changes after
@@ -793,18 +810,9 @@ static enum rps t_should_relay_response( struct cell *Trans , int new_code,
 
 		if ( !(Trans->flags&T_NO_DNS_FAILOVER_FLAG) &&
 		Trans->uac[picked_branch].proxy!=NULL ) {
-			/* is is a DNS failover scenario? - according to RFC 3263
-			 * this means 503 reply or timeout with no reply */
-			DBG("DEBUG:tm:t_should_relay_response: dns-failover test: "
-				"branch=%d, last_recv=%d, flags=%X\n",
-				picked_branch, Trans->uac[picked_branch].last_received,
-				Trans->uac[picked_branch].flags);
-			if ( Trans->uac[picked_branch].last_received==503 ||
-			(Trans->uac[picked_branch].last_received==408 && 
-			(Trans->uac[picked_branch].flags&T_UAC_HAS_RECV_REPLY)==0)
-			 ) {
-				DBG("DEBUG:tm:t_should_relay_response: trying DNS-based "
-					"failover\n");
+			/* is is a DNS failover scenario, according to RFC 3263 ? */
+			if (is_3263_failure(Trans)) {
+				LM_DBG("trying DNS-based failover\n");
 				/* do DNS failover -> add new branches */
 				if (do_dns_failover( Trans )!=0) {
 					/* skip the failed added branches */
@@ -890,29 +898,27 @@ int t_retransmit_reply( struct cell *t )
 	LOCK_REPLIES( t );
 
 	if (!t->uas.response.buffer.s) {
-		DBG("DEBUG:tm:t_retransmit_reply: nothing to retransmit\n");
+		LM_DBG("nothing to retransmit\n");
 		goto error;
 	}
 
 	/* response.dst.send_sock should be valid all the time now, as it's taken
 	   from original request -bogdan */
 	if (t->uas.response.dst.send_sock==0) {
-		LOG(L_CRIT,"BUG:tm:t_retransmit_reply: something to retransmit, but"
-			"send_sock is NULL\n");
+		LM_CRIT("something to retransmit, but send_sock is NULL\n");
 		goto error;
 	}
 
 	len=t->uas.response.buffer.len;
 	if ( len==0 || len>BUF_SIZE )  {
-		DBG("DEBUG:tm:t_retransmit_reply: zero length or too big "
-			"to retransmit: %d\n", len);
+		LM_DBG("zero length or too big to retransmit: %d\n", len);
 		goto error;
 	}
 	memcpy( b, t->uas.response.buffer.s, len );
 	UNLOCK_REPLIES( t );
 	SEND_PR_BUFFER( & t->uas.response, b, len );
-	DBG("DEBUG:tm:t_retransmit_reply: buf=%p: %.9s..., shmem=%p: %.9s\n", 
-		b, b, t->uas.response.buffer.s, t->uas.response.buffer.s );
+	LM_DBG("buf=%p: %.9s..., shmem=%p: %.9s\n",b, b, t->uas.response.buffer.s,
+			t->uas.response.buffer.s );
 	return 1;
 
 error:
@@ -969,14 +975,14 @@ void cleanup_uac_timers( struct cell *t )
 		reset_timer( &t->uac[i].request.retr_timer );
 		reset_timer( &t->uac[i].request.fr_timer );
 	}
-	DBG("DEBUG: cleanup_uac_timers: RETR/FR timers reset\n");
+	LM_DBG("RETR/FR timers reset\n");
 }
 
 static int store_reply( struct cell *trans, int branch, struct sip_msg *rpl)
 {
 #		ifdef EXTRA_DEBUG
 		if (trans->uac[branch].reply) {
-			LOG(L_ERR, "ERROR: replacing stored reply; aborting\n");
+			LM_ERR("replacing stored reply; aborting\n");
 			abort();
 		}
 #		endif
@@ -991,7 +997,7 @@ static int store_reply( struct cell *trans, int branch, struct sip_msg *rpl)
 			trans->uac[branch].reply = sip_msg_cloner( rpl, 0 );
 
 		if (! trans->uac[branch].reply ) {
-			LOG(L_ERR, "ERROR: store_reply: can't alloc' clone memory\n");
+			LM_ERR("failed to alloc' clone memory\n");
 			return 0;
 		}
 
@@ -1034,7 +1040,7 @@ enum rps relay_reply( struct cell *t, struct sip_msg *p_msg, int branch,
 	/* *** store and relay message as needed *** */
 	reply_status = t_should_relay_response(t, msg_status, branch, 
 		&save_clone, &relay, cancel_bitmap, p_msg );
-	DBG("DEBUG:tm:relay_reply: branch=%d, save=%d, relay=%d\n",
+	LM_DBG("branch=%d, save=%d, relay=%d\n",
 		branch, save_clone, relay );
 
 	/* store the message if needed */
@@ -1094,8 +1100,7 @@ enum rps relay_reply( struct cell *t, struct sip_msg *p_msg, int branch,
 			}
 		}
 		if (!buf) {
-			LOG(L_ERR, "ERROR:tm:relay_reply: "
-				"no mem for outbound reply buffer\n");
+			LM_ERR("no mem for outbound reply buffer\n");
 			goto error02;
 		}
 
@@ -1108,7 +1113,7 @@ enum rps relay_reply( struct cell *t, struct sip_msg *p_msg, int branch,
 		uas_rb->buffer.s = (char*)shm_resize( uas_rb->buffer.s, res_len +
 			(msg_status<200 ?  REPLY_OVERBUFFER_LEN : 0));
 		if (!uas_rb->buffer.s) {
-			LOG(L_ERR, "ERROR:tm:relay_reply: cannot alloc reply shmem\n");
+			LM_ERR("no more share memory\n");
 			goto error03;
 		}
 		uas_rb->buffer.len = res_len;
@@ -1141,7 +1146,7 @@ enum rps relay_reply( struct cell *t, struct sip_msg *p_msg, int branch,
 	/* send it now (from the private buffer) */
 	if (relay >= 0) {
 		SEND_PR_BUFFER( uas_rb, buf, res_len );
-		DBG("DEBUG:tm:relay_reply: sent buf=%p: %.9s..., shmem=%p: %.9s\n", 
+		LM_DBG("sent buf=%p: %.9s..., shmem=%p: %.9s\n", 
 			buf, buf, uas_rb->buffer.s, uas_rb->buffer.s );
 		if (!totag_retr && has_tran_tmcbs(t, TMCB_RESPONSE_OUT) ) {
 			cb_s.s = buf;
@@ -1201,7 +1206,7 @@ enum rps local_reply( struct cell *t, struct sip_msg *p_msg, int branch,
 
 	reply_status=t_should_relay_response( t, msg_status, branch,
 		&local_store, &local_winner, cancel_bitmap, p_msg );
-	DBG("DEBUG:tm:local_reply: branch=%d, save=%d, winner=%d\n",
+	LM_DBG("branch=%d, save=%d, winner=%d\n",
 		branch, local_store, local_winner );
 	if (local_store) {
 		if (!store_reply(t, branch, p_msg))
@@ -1229,13 +1234,13 @@ enum rps local_reply( struct cell *t, struct sip_msg *p_msg, int branch,
 	if ( local_winner >= 0 ) {
 		if (winning_code < 200) {
 			if (!totag_retr && has_tran_tmcbs(t,TMCB_LOCAL_RESPONSE_OUT)) {
-				DBG("DEBUG: Passing provisional reply %d to FIFO "
-					"application\n", winning_code);
+				LM_DBG("Passing provisional reply %d to FIFO application\n",
+						winning_code);
 				run_trans_callbacks( TMCB_LOCAL_RESPONSE_OUT, t, 0,
 					winning_msg, winning_code);
 			}
 		} else {
-			DBG("DEBUG:tm:local_reply: local transaction completed\n");
+			LM_DBG("local transaction completed\n");
 			if (!totag_retr && has_tran_tmcbs(t,TMCB_LOCAL_COMPLETED) ) {
 				run_trans_callbacks( TMCB_LOCAL_COMPLETED, t, 0,
 					winning_msg, winning_code );
@@ -1286,8 +1291,7 @@ int reply_received( struct sip_msg  *p_msg )
 	msg_status=p_msg->REPLY_STATUS;
 
 	uac=&t->uac[branch];
-	DBG("DEBUG:tm:reply_received: org. status uas=%d, "
-		"uac[%d]=%d local=%d is_invite=%d)\n",
+	LM_DBG("org. status uas=%d, uac[%d]=%d local=%d is_invite=%d)\n",
 		t->uas.status, branch, uac->last_received, 
 		is_local(t), is_invite(t));
 	last_uac_status=uac->last_received;
@@ -1300,7 +1304,7 @@ int reply_received( struct sip_msg  *p_msg )
 		if ( msg_status >= 200 ) {
 				reset_timer( &uac->local_cancel.fr_timer);
 		}
-		DBG("DEBUG:tm:reply_received: reply to local CANCEL processed\n");
+		LM_DBG("reply to local CANCEL processed\n");
 		goto done;
 	}
 
@@ -1319,8 +1323,14 @@ int reply_received( struct sip_msg  *p_msg )
 	if (is_invite(t) && ((msg_status >= 300) ||
 	(is_local(t) && !no_autoack(t) && msg_status >= 200) )) {
 		if (send_ack(p_msg, t, branch)!=0)
-			LOG(L_ERR, "ERROR:tm:reply_received: failed to send ACK "
-				"(local=%s)\n", is_local(t)?"yes":"no");
+			LM_ERR("failed to send ACK (local=%s)\n", is_local(t)?"yes":"no");
+	}
+
+	/* if it is an 503, parse the RETRY-AFTER header - we need
+	 * it later */
+	if ( msg_status==503 && (t->flags&T_NO_DNS_FAILOVER_FLAG)==0 &&
+	parse_headers( p_msg, HDR_RETRY_AFTER_F, 0)==-1) {
+		LM_ERR("failed to parse reply (looking for Retry-After\n");
 	}
 
 	/* processing of on_reply block */
@@ -1343,7 +1353,7 @@ int reply_received( struct sip_msg  *p_msg )
 				UNLOCK_REPLIES( t );
 				set_avp_list( backup_list );
 			}
-			DBG("DEBUG:tm:reply_received: dropping provisional reply %d\n",
+			LM_DBG("dropping provisional reply %d\n",
 				msg_status);
 			goto done;
 		}
@@ -1393,7 +1403,7 @@ int reply_received( struct sip_msg  *p_msg )
 		}
 	}
 	
-	if (reply_status == RPS_ERROR || reply_status== RPS_DISCARDED)
+	if (reply_status!=RPS_PROVISIONAL)
 		goto done;
 	
 	/* update FR/RETR timers on provisional replies */
@@ -1407,7 +1417,7 @@ int reply_received( struct sip_msg  *p_msg )
 			 */
 			backup_list = set_avp_list(&t->user_avps);
 			if (!fr_inv_avp2timer(&timer)) {
-				DBG("DEBUG:tm:reply_received: FR_INV_TIMER = %lld\n", timer);
+				LM_DBG("FR_INV_TIMER = %lld\n", timer);
 				set_timer(&uac->request.fr_timer,
 					FR_INV_TIMER_LIST, &timer);
 				t->flags |= T_NOISY_CTIMER_FLAG;
@@ -1456,7 +1466,7 @@ int t_reply_with_body( struct cell *trans, unsigned int code, str *text,
 		hdr_lump = add_lump_rpl( trans->uas.request, new_header->s,
 			new_header->len, LUMP_RPL_HDR );
 		if ( !hdr_lump ) {
-			LOG(L_ERR,"ERROR:tm:t_reply_with_body: cannot add hdr lump\n");
+			LM_ERR("failed to add hdr lump\n");
 			goto error;
 		}
 	} else {
@@ -1468,7 +1478,7 @@ int t_reply_with_body( struct cell *trans, unsigned int code, str *text,
 		body_lump = add_lump_rpl( trans->uas.request, body->s, body->len,
 			LUMP_RPL_BODY );
 		if (body_lump==0) {
-			LOG(L_ERR,"ERROR:tm:t_reply_with_body: cannot add body lump\n");
+			LM_ERR("failed add body lump\n");
 			goto error_1;
 		}
 	} else {
@@ -1492,12 +1502,11 @@ int t_reply_with_body( struct cell *trans, unsigned int code, str *text,
 	}
 
 	if (rpl.s==0) {
-		LOG(L_ERR,"ERROR:tm:t_reply_with_body: failed in doing "
-			"build_res_buf_from_sip_req()\n");
+		LM_ERR("failed in doing build_res_buf_from_sip_req()\n");
 		goto error;
 	}
 
-	DBG("DEBUG:tm:t_reply_with_body: buffer computed\n");
+	LM_DBG("buffer computed\n");
 	ret=_reply_light( trans, rpl.s, rpl.len, code, to_tag->s, to_tag->len,
 			1 /* lock replies */, &bm );
 
@@ -1514,190 +1523,3 @@ error:
 	return -1;
 }
 
-
-
-static int parse_transid(str* s, unsigned int* index, unsigned int* label)
-{
-	char* buf;
-
-	if (!s || !index || !label) {
-		LOG(L_ERR, "ERROR:tm:parse_transid: Invalid parameter value\n");
-		return -1;
-	}
-
-	buf = (char*)pkg_malloc(s->len + 1);
-	if (!buf) {
-		LOG(L_ERR, "ERROR:tm:parse_transid: No memory left\n");
-		return -1;
-	}
-
-	memcpy(buf, s->s, s->len + 1);
-	buf[s->len] = '\0';
-	
-	if (sscanf(buf, "%u:%u", index, label) != 2) {
-		LOG(L_ERR, "ERROR:tm:parse_transid: Invalid trans_id (%s)\n", buf);
-		pkg_free(buf);
-		return -1;
-	}
-
-	DBG("DEBUG:tm:parse_transid: hash_index=%u label=%u\n", *index, *label);
-	pkg_free(buf);
-	return 0;
-}
-
-
-
-static int send_reply(struct cell *trans, unsigned int code, str* text, str* body,
-													str* headers, str* to_tag)
-{
-	struct lump_rpl *hdr_lump, *body_lump;
-	str rpl;
-	int ret;
-	struct bookmark bm;
-
-	/* mark the transaction as replied */
-	if (code >= 200) set_kr(REQ_RPLD);
-
-	/* add the lumps for new_header and for body (by bogdan) */
-	if (headers && headers->len) {
-		hdr_lump = add_lump_rpl(trans->uas.request, headers->s, headers->len,
-			LUMP_RPL_HDR);
-		if (!hdr_lump) {
-			LOG(L_ERR, "ERROR:tm:send_reply: cannot add hdr lump\n");
-			goto sr_error;
-		}
-	} else {
-		hdr_lump = 0;
-	}
-
-	/* body lump */
-	if (body && body->len) {
-		body_lump = add_lump_rpl(trans->uas.request, body->s, body->len,
-			LUMP_RPL_BODY);
-		if (body_lump == 0) {
-			LOG(L_ERR,"ERROR:tm:send_reply: cannot add body lump\n");
-			goto sr_error_1;
-		}
-	} else {
-		body_lump = 0;
-	}
-
-	rpl.s = build_res_buf_from_sip_req(code, text, to_tag, 
-		trans->uas.request, (unsigned int*)&rpl.len, &bm);
-
-	/* since the msg (trans->uas.request) is a clone into shm memory, to avoid
-	 * memory leak or crashing (lumps are create in private memory) I will
-	 * remove the lumps by myself here (bogdan) */
-	if (hdr_lump) {
-		unlink_lump_rpl(trans->uas.request, hdr_lump);
-		free_lump_rpl(hdr_lump);
-	}
-	if (body_lump) {
-		unlink_lump_rpl(trans->uas.request, body_lump);
-		free_lump_rpl(body_lump);
-	}
-
-	if (rpl.s == 0) {
-		LOG(L_ERR,"ERROR:tm:send_reply: failed in build_res_buf_from_sip_req\n");
-		goto sr_error;
-	}
-
-	ret = _reply_light(trans, rpl.s, rpl.len, code, to_tag->s, to_tag->len,
-			1 /* lock replies */, &bm);
-
-	/* unref since this it's used only internaly */
-	UNREF(trans);
-	return ret;
-sr_error_1:
-	if (hdr_lump) {
-		unlink_lump_rpl(trans->uas.request, hdr_lump);
-		free_lump_rpl(hdr_lump);
-	}
-sr_error:
-	return -1;
-}
-
-
-
-int unixsock_t_reply(str* msg)
-{
-	int ret;
-	struct cell *trans;
-	static char new_headers[MAX_HEADER];
-	str code, reason, transid, headers, body, to_tag;
-	unsigned int hash_index, label, icode;
-
-	headers.s = new_headers;
-	headers.len = MAX_HEADER;
-
-	if (unixsock_read_line(&code, msg) != 0) {
-		unixsock_reply_asciiz("400 Reason code expected\n");
-		goto err;
-	}
-
-	icode = str2s(code.s, code.len, &ret);
-	if (ret) {
-		unixsock_reply_printf("400 Reason code has wrong format\n");
-		goto err;
-	}
-
-	if (unixsock_read_line(&reason, msg) != 0) {
-		unixsock_reply_asciiz("400 Reason phrase expected\n");
-		goto err;
-	}
-
-	if (unixsock_read_line(&transid, msg) != 0) {
-		unixsock_reply_asciiz("400 Transaction ID expected\n");
-		goto err;
-	}
-
-	if (parse_transid(&transid, &hash_index, &label) < 0) {
-		unixsock_reply_asciiz("400 Error while parsing transaction ID\n");
-		goto err;
-	}
-
-	if (unixsock_read_line(&to_tag, msg) != 0) {
-		unixsock_reply_asciiz("400 To tag expected\n");
-		goto err;
-	}
-
-	     /* read the new headers */
-	if (unixsock_read_lineset(&headers, msg) < 0) {
-		unixsock_reply_asciiz("400 Error while reading new headers\n");
-		goto err;
-	}
-
-	DBG("lineset: %.*s\n", headers.len, headers.s);
-	     
-	/*  body can be empty ... */
-	if (unixsock_read_body(&body, msg) < 0) {
-		unixsock_reply_asciiz("400 Error while reading body\n");
-		goto err;
-	}
-
-	DBG("body: %.*s\n", body.len, body.s);
-	
-	if (t_lookup_ident(&trans, hash_index, label) < 0) {
-		LOG(L_ERR,"ERROR:tm:unixsock_t_reply: lookup failed\n");
-		unixsock_reply_asciiz("481 No such transaction\n");
-		goto err;
-	}
-
-	     /* it's refcounted now, t_reply_with body unrefs for me -- I can 
-	      * continue but may not use T anymore  
-	      */
-	ret = send_reply(trans, icode, &reason, &body, &headers, &to_tag);
-	if (ret < 0) {
-		LOG(L_ERR, "ERROR:tm:unixsock_t_reply: reply failed\n");
-		unixsock_reply_asciiz("500 Reply failed\n");
-		goto err;
-	}
-
-	unixsock_reply_asciiz("200 Succeeded\n");
-	unixsock_reply_send();
-	return 1;
-
- err:
-	unixsock_reply_send();
-	return -1;
-}
