@@ -1,5 +1,5 @@
 /*
- * $Id: xl_lib.h 1827 2007-03-12 15:22:53Z bogdan_iancu $
+ * $Id: xl_lib.h 2725 2007-09-09 20:55:56Z miconda $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -23,9 +23,9 @@
 #ifndef _XL_LIB_H_
 #define _XL_LIB_H_
 
-#include "../../items.h"
+#include "../../pvar.h"
 
-int xl_print_log(struct sip_msg* msg, xl_elem_p log, char *buf, int *len);
+int xl_print_log(struct sip_msg* msg, pv_elem_p log, char *buf, int *len);
 
 #endif
 
