@@ -1,5 +1,5 @@
 /*
- * $Id: udp_server.h 1827 2007-03-12 15:22:53Z bogdan_iancu $
+ * $Id: udp_server.h 2565 2007-08-01 21:40:18Z miconda $
  *
  * Copyright (C) 2001-2003 FhG Fokus
  *
@@ -28,9 +28,6 @@
 #include <sys/socket.h>
 #include "ip_addr.h"
 
-#define MAX_RECV_BUFFER_SIZE	256*1024
-#define BUFFER_INCREMENT	2048
-
 
 int udp_init(struct socket_info* si);
 int udp_send(struct socket_info* source,char *buf, unsigned len,
